/* Generated by tools/gen_mathml_operators_h.py */
{U"\x0021",   MATHML_OP_PREFIX, 0, 5, 0}, // !
{U"\x0021",  MATHML_OP_POSTFIX, 1, 0, 0}, // !
{U"\x0021\x0021",  MATHML_OP_POSTFIX, 1, 0, 0}, // !!
{U"\x0021\x003D",    MATHML_OP_INFIX, 4, 4, 0}, // !=
{U"\x0025",    MATHML_OP_INFIX, 3, 3, 0}, // percent sign
{U"\x0026",    MATHML_OP_INFIX, 5, 5, 0}, // &amp;
{U"\x0026",   MATHML_OP_PREFIX, 0, 5, 0}, // &amp;
{U"\x0026",  MATHML_OP_POSTFIX, 0, 0, 0}, // &amp;
{U"\x0026\x0026",    MATHML_OP_INFIX, 4, 4, 0}, // &amp;&amp;
{U"\x0027",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_ACCENT}, // '
{U"\x0028",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_MIRRORABLE}, // (
{U"\x0029",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_MIRRORABLE}, // )
{U"\x002A",    MATHML_OP_INFIX, 3, 3, 0}, // *
{U"\x002A\x002A",    MATHML_OP_INFIX, 1, 1, 0}, // **
{U"\x002A\x003D",    MATHML_OP_INFIX, 4, 4, 0}, // *=
{U"\x002B",    MATHML_OP_INFIX, 4, 4, 0}, // +
{U"\x002B",   MATHML_OP_PREFIX, 0, 1, 0}, // +
{U"\x002B\x002B",   MATHML_OP_PREFIX, 0, 2, 0}, // ++
{U"\x002B\x002B",  MATHML_OP_POSTFIX, 0, 0, 0}, // ++
{U"\x002B\x003D",    MATHML_OP_INFIX, 4, 4, 0}, // +=
{U"\x002C",    MATHML_OP_INFIX, 0, 3, MATHML_OP_SEPARATOR}, // ,
{U"\x002D",    MATHML_OP_INFIX, 4, 4, 0}, // -
{U"\x002D",   MATHML_OP_PREFIX, 0, 1, 0}, // -
{U"\x002D\x002D",   MATHML_OP_PREFIX, 0, 2, 0}, // --
{U"\x002D\x002D",  MATHML_OP_POSTFIX, 0, 0, 0}, // --
{U"\x002D\x003D",    MATHML_OP_INFIX, 4, 4, 0}, // -=
{U"\x002D\x003E",    MATHML_OP_INFIX, 5, 5, 0}, // ->
{U"\x002E",    MATHML_OP_INFIX, 3, 3, 0}, // .
{U"\x002E\x002E",  MATHML_OP_POSTFIX, 0, 0, 0}, // ..
{U"\x002E\x002E\x002E",  MATHML_OP_POSTFIX, 0, 0, 0}, // ...
{U"\x002F",    MATHML_OP_INFIX, 1, 1, MATHML_OP_VERTICAL}, // solidus
{U"\x002F\x002F",    MATHML_OP_INFIX, 1, 1, 0}, // //
{U"\x002F\x003D",    MATHML_OP_INFIX, 4, 4, 0}, // /=
{U"\x003A",    MATHML_OP_INFIX, 1, 2, 0}, // :
{U"\x003A\x003D",    MATHML_OP_INFIX, 4, 4, 0}, // :=
{U"\x003B",    MATHML_OP_INFIX, 0, 3, MATHML_OP_SEPARATOR}, // ;
{U"\x003B",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_SEPARATOR}, // ;
{U"\x003C",    MATHML_OP_INFIX, 5, 5, 0}, // &lt;
{U"\x003C\x003D",    MATHML_OP_INFIX, 5, 5, 0}, // &lt;=
{U"\x003C\x003E",    MATHML_OP_INFIX, 1, 1, 0}, // &lt;>
{U"\x003C\x20D2",    MATHML_OP_INFIX, 5, 5, 0}, // &nvlt;
{U"\x003D",    MATHML_OP_INFIX, 5, 5, MATHML_OP_HORIZONTAL}, // =
{U"\x003D\x003D",    MATHML_OP_INFIX, 4, 4, 0}, // ==
{U"\x003E",    MATHML_OP_INFIX, 5, 5, 0}, // >
{U"\x003E\x003D",    MATHML_OP_INFIX, 5, 5, 0}, // >=
{U"\x003E\x20D2",    MATHML_OP_INFIX, 5, 5, 0}, // &nvgt;
{U"\x003F",    MATHML_OP_INFIX, 1, 1, 0}, // ?
{U"\x0040",    MATHML_OP_INFIX, 1, 1, 0}, // @
{U"\x005B",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_MIRRORABLE}, // [
{U"\x005C",    MATHML_OP_INFIX, 0, 0, 0}, // reverse solidus
{U"\x005D",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_MIRRORABLE}, // ]
{U"\x005E",    MATHML_OP_INFIX, 1, 1, MATHML_OP_HORIZONTAL}, // ^
{U"\x005E",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &Hat; circumflex accent
{U"\x005F",    MATHML_OP_INFIX, 1, 1, MATHML_OP_STRETCHY|MATHML_OP_HORIZONTAL}, // _ low line
{U"\x005F",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // _ low line
{U"\x0060",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_ACCENT}, // &DiacriticalGrave;
{U"\x006C\x0069\x006D",   MATHML_OP_PREFIX, 0, 3, MATHML_OP_MOVABLELIMITS}, // lim
{U"\x006D\x0061\x0078",   MATHML_OP_PREFIX, 0, 3, MATHML_OP_MOVABLELIMITS}, // max
{U"\x006D\x0069\x006E",   MATHML_OP_PREFIX, 0, 3, MATHML_OP_MOVABLELIMITS}, // min
{U"\x007B",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_MIRRORABLE}, // {
{U"\x007C",    MATHML_OP_INFIX, 2, 2, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // &VerticalLine; |
{U"\x007C",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // |
{U"\x007C",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // |
{U"\x007C\x007C",    MATHML_OP_INFIX, 2, 2, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // ||
{U"\x007C\x007C",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // multiple character operator: ||
{U"\x007C\x007C",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // multiple character operator: ||
{U"\x007C\x007C\x007C",    MATHML_OP_INFIX, 2, 2, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // multiple character operator: |||
{U"\x007C\x007C\x007C",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // multiple character operator: |||
{U"\x007C\x007C\x007C",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // multiple character operator: |||
{U"\x007D",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_MIRRORABLE}, // }
{U"\x007E",    MATHML_OP_INFIX, 2, 2, MATHML_OP_STRETCHY|MATHML_OP_HORIZONTAL}, // ~
{U"\x007E",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // ~ tilde
{U"\x00A8",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_ACCENT}, // &DoubleDot;
{U"\x00AC",   MATHML_OP_PREFIX, 2, 1, 0}, // not sign
{U"\x00AF",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &OverBar;
{U"\x00B0",  MATHML_OP_POSTFIX, 0, 0, 0}, // degree sign
{U"\x00B1",    MATHML_OP_INFIX, 4, 4, 0}, // &PlusMinus;
{U"\x00B1",   MATHML_OP_PREFIX, 0, 1, 0}, // &PlusMinus;
{U"\x00B4",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_ACCENT}, // &DiacriticalAcute;
{U"\x00B7",    MATHML_OP_INFIX, 4, 4, 0}, // &CenterDot;
{U"\x00B8",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_ACCENT}, // &Cedilla;
{U"\x00D7",    MATHML_OP_INFIX, 4, 4, 0}, // multiplication sign
{U"\x00F7",    MATHML_OP_INFIX, 4, 4, 0}, // division sign
{U"\x02C6",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // modifier letter circumflex accent
{U"\x02C7",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &Hacek; caron
{U"\x02C9",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // modifier letter macron
{U"\x02CA",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_ACCENT}, // modifier letter acute accent
{U"\x02CB",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_ACCENT}, // modifier letter grave accent
{U"\x02CD",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // modifier letter low macron
{U"\x02D8",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_ACCENT}, // &Breve;
{U"\x02D9",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_ACCENT}, // &DiacriticalDot;
{U"\x02DA",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_ACCENT}, // ring above
{U"\x02DC",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &DiacriticalTilde; small tilde
{U"\x02DD",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_ACCENT}, // &DiacriticalDoubleAcute;
{U"\x02F7",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // modifier letter low tilde
{U"\x0302",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // combining circumflex accent
{U"\x0311",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_ACCENT}, // &DownBreve;
{U"\x0332",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &UnderBar;
{U"\x03F6",    MATHML_OP_INFIX, 5, 5, 0}, // greek reversed lunate epsilon symbol
{U"\x2016",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &Vert; &Verbar;
{U"\x2016",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_VERTICAL}, // &Vert; &Verbar;
{U"\x2016",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_VERTICAL}, // &Vert; &Verbar;
{U"\x2018",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_FENCE|MATHML_OP_MIRRORABLE}, // &OpenCurlyQuote;
{U"\x2019",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_FENCE|MATHML_OP_MIRRORABLE}, // &CloseCurlyQuote;
{U"\x201C",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_FENCE|MATHML_OP_MIRRORABLE}, // &OpenCurlyDoubleQuote;
{U"\x201D",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_FENCE|MATHML_OP_MIRRORABLE}, // &CloseCurlyDoubleQuote;
{U"\x2022",    MATHML_OP_INFIX, 4, 4, 0}, // bullet
{U"\x2026",    MATHML_OP_INFIX, 0, 0, 0}, // horizontal ellipsis
{U"\x2032",  MATHML_OP_POSTFIX, 0, 2, 0}, // prime
{U"\x203E",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // overline
{U"\x2044",    MATHML_OP_INFIX, 4, 4, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // fraction slash
{U"\x2061",    MATHML_OP_INFIX, 0, 0, 0}, // &ApplyFunction;
{U"\x2062",    MATHML_OP_INFIX, 0, 0, 0}, // &InvisibleTimes;
{U"\x2063",    MATHML_OP_INFIX, 0, 0, MATHML_OP_SEPARATOR}, // &InvisibleComma;
{U"\x2064",    MATHML_OP_INFIX, 0, 0, 0}, // invisible plus
{U"\x20D0",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &#x20D0;
{U"\x20D1",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &#x20D1;
{U"\x20D6",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &#x20D6;
{U"\x20D7",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &#x20D7;
{U"\x20DB",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_ACCENT}, // &TripleDot;
{U"\x20DC",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_ACCENT}, // combining four dots above
{U"\x20E1",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &#x20E1;
{U"\x2145",   MATHML_OP_PREFIX, 2, 1, 0}, // &CapitalDifferentialD;
{U"\x2146",   MATHML_OP_PREFIX, 2, 0, 0}, // &DifferentialD;
{U"\x2190",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &LeftArrow;
{U"\x2190\x200B",    MATHML_OP_INFIX, 5, 5, 0}, // &ShortLeftArrow;
{U"\x2191",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &UpArrow;
{U"\x2191\x200B",    MATHML_OP_INFIX, 2, 2, 0}, // &ShortUpArrow;
{U"\x2192",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &RightArrow;
{U"\x2192\x200B",    MATHML_OP_INFIX, 5, 5, 0}, // &ShortRightArrow;
{U"\x2193",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &DownArrow;
{U"\x2193\x200B",    MATHML_OP_INFIX, 2, 2, 0}, // &ShortDownArrow;
{U"\x2194",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &LeftRightArrow;
{U"\x2195",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &UpDownArrow;
{U"\x2196",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &UpperLeftArrow;
{U"\x2197",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &UpperRightArrow;
{U"\x2198",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_HORIZONTAL}, // &LowerRightArrow;
{U"\x2199",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_HORIZONTAL}, // &LowerLeftArrow;
{U"\x219A",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // leftwards arrow with stroke
{U"\x219B",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // rightwards arrow with stroke
{U"\x219C",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // leftwards wave arrow
{U"\x219D",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // rightwards wave arrow
{U"\x219E",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // leftwards two headed arrow
{U"\x219F",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_VERTICAL}, // upwards two headed arrow
{U"\x21A0",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // rightwards two headed arrow
{U"\x21A1",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // downwards two headed arrow
{U"\x21A2",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // leftwards arrow with tail
{U"\x21A3",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // rightwards arrow with tail
{U"\x21A4",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &LeftTeeArrow;
{U"\x21A5",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &UpTeeArrow;
{U"\x21A6",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &RightTeeArrow;
{U"\x21A7",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &DownTeeArrow;
{U"\x21A8",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // up down arrow with base
{U"\x21A9",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &hookleftarrow; &larrhk;
{U"\x21AA",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &hookrightarrow; &rarrhk;
{U"\x21AB",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // leftwards arrow with loop
{U"\x21AC",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // rightwards arrow with loop
{U"\x21AD",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // left right wave arrow
{U"\x21AE",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // left right arrow with stroke
{U"\x21AF",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // downwards zigzag arrow
{U"\x21B0",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // upwards arrow with tip leftwards
{U"\x21B1",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // upwards arrow with tip rightwards
{U"\x21B2",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // downwards arrow with tip leftwards
{U"\x21B3",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // downwards arrow with tip rightwards
{U"\x21B4",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_HORIZONTAL}, // rightwards arrow with corner downwards
{U"\x21B5",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // downwards arrow with corner leftwards
{U"\x21B6",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // anticlockwise top semicircle arrow
{U"\x21B7",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // clockwise top semicircle arrow
{U"\x21B8",    MATHML_OP_INFIX, 5, 5, 0}, // north west arrow to long bar
{U"\x21B9",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // leftwards arrow to bar over rightwards arrow to bar
{U"\x21BA",    MATHML_OP_INFIX, 5, 5, 0}, // anticlockwise open circle arrow
{U"\x21BB",    MATHML_OP_INFIX, 5, 5, 0}, // clockwise open circle arrow
{U"\x21BC",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &LeftVector;
{U"\x21BD",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &DownLeftVector;
{U"\x21BE",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &RightUpVector;
{U"\x21BF",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &LeftUpVector;
{U"\x21C0",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &RightVector;
{U"\x21C1",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &DownRightVector;
{U"\x21C2",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &RightDownVector;
{U"\x21C3",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &LeftDownVector;
{U"\x21C4",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &RightArrowLeftArrow;
{U"\x21C5",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &UpArrowDownArrow;
{U"\x21C6",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &LeftArrowRightArrow;
{U"\x21C7",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // leftwards paired arrows
{U"\x21C8",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // upwards paired arrows
{U"\x21C9",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // rightwards paired arrows
{U"\x21CA",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // downwards paired arrows
{U"\x21CB",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &ReverseEquilibrium;
{U"\x21CC",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &Equilibrium;
{U"\x21CD",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // leftwards double arrow with stroke
{U"\x21CE",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // left right double arrow with stroke
{U"\x21CF",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // rightwards double arrow with stroke
{U"\x21D0",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &DoubleLeftArrow;
{U"\x21D1",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &DoubleUpArrow;
{U"\x21D2",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &Implies; &DoubleRightArrow;
{U"\x21D3",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &DoubleDownArrow;
{U"\x21D4",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &DoubleLeftRightArrow;
{U"\x21D5",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &DoubleUpDownArrow;
{U"\x21DA",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // leftwards triple arrow
{U"\x21DB",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // rightwards triple arrow
{U"\x21DC",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // leftwards squiggle arrow
{U"\x21DD",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // rightwards squiggle arrow
{U"\x21DE",    MATHML_OP_INFIX, 5, 5, 0}, // upwards arrow with double stroke
{U"\x21DF",    MATHML_OP_INFIX, 5, 5, 0}, // downwards arrow with double stroke
{U"\x21E0",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // leftwards dashed arrow
{U"\x21E1",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // upwards dashed arrow
{U"\x21E2",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // rightwards dashed arrow
{U"\x21E3",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // downwards dashed arrow
{U"\x21E4",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &LeftArrowBar;
{U"\x21E5",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &RightArrowBar;
{U"\x21E6",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // leftwards white arrow
{U"\x21E7",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // upwards white arrow
{U"\x21E8",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // rightwards white arrow
{U"\x21E9",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // downwards white arrow
{U"\x21EA",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // upwards white arrow from bar
{U"\x21EB",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // upwards white arrow on pedestal
{U"\x21EC",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // upwards white arrow on pedestal with horizontal bar
{U"\x21ED",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // upwards white arrow on pedestal with vertical bar
{U"\x21EE",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // upwards white double arrow
{U"\x21EF",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // upwards white double arrow on pedestal
{U"\x21F0",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // rightwards white arrow from wall
{U"\x21F1",    MATHML_OP_INFIX, 5, 5, 0}, // north west arrow to corner
{U"\x21F2",    MATHML_OP_INFIX, 5, 5, 0}, // south east arrow to corner
{U"\x21F3",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // up down white arrow
{U"\x21F4",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // right arrow with small circle
{U"\x21F5",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &DownArrowUpArrow;
{U"\x21F6",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // three rightwards arrows
{U"\x21F7",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // leftwards arrow with vertical stroke
{U"\x21F8",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // rightwards arrow with vertical stroke
{U"\x21F9",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // left right arrow with vertical stroke
{U"\x21FA",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // leftwards arrow with double vertical stroke
{U"\x21FB",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // rightwards arrow with double vertical stroke
{U"\x21FC",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // left right arrow with double vertical stroke
{U"\x21FD",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // leftwards open-headed arrow
{U"\x21FE",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // rightwards open-headed arrow
{U"\x21FF",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // left right open-headed arrow
{U"\x2200",   MATHML_OP_PREFIX, 2, 1, 0}, // &ForAll;
{U"\x2201",    MATHML_OP_INFIX, 1, 2, 0}, // complement
{U"\x2202",   MATHML_OP_PREFIX, 2, 1, 0}, // &PartialD;
{U"\x2203",   MATHML_OP_PREFIX, 2, 1, 0}, // &Exists;
{U"\x2204",   MATHML_OP_PREFIX, 2, 1, 0}, // &NotExists;
{U"\x2206",    MATHML_OP_INFIX, 3, 3, 0}, // increment
{U"\x2207",   MATHML_OP_PREFIX, 2, 1, 0}, // &Del;
{U"\x2208",    MATHML_OP_INFIX, 5, 5, 0}, // &Element;
{U"\x2209",    MATHML_OP_INFIX, 5, 5, 0}, // &NotElement;
{U"\x220A",    MATHML_OP_INFIX, 5, 5, 0}, // small element of
{U"\x220B",    MATHML_OP_INFIX, 5, 5, 0}, // &SuchThat; &ReverseElement;
{U"\x220C",    MATHML_OP_INFIX, 5, 5, 0}, // &NotReverseElement;
{U"\x220D",    MATHML_OP_INFIX, 5, 5, 0}, // small contains as member
{U"\x220E",    MATHML_OP_INFIX, 3, 3, 0}, // end of proof
{U"\x220F",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_MOVABLELIMITS|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // &Product;
{U"\x2210",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_MOVABLELIMITS|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // &Coproduct;
{U"\x2211",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_MOVABLELIMITS|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_MIRRORABLE}, // &Sum;
{U"\x2212",    MATHML_OP_INFIX, 4, 4, 0}, // official Unicode minus sign
{U"\x2212",   MATHML_OP_PREFIX, 0, 1, 0}, // official Unicode minus sign
{U"\x2213",    MATHML_OP_INFIX, 4, 4, 0}, // &MinusPlus;
{U"\x2213",   MATHML_OP_PREFIX, 0, 1, 0}, // &MinusPlus;
{U"\x2214",    MATHML_OP_INFIX, 4, 4, 0}, // dot plus
{U"\x2215",    MATHML_OP_INFIX, 4, 4, MATHML_OP_STRETCHY|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // division slash
{U"\x2216",    MATHML_OP_INFIX, 4, 4, MATHML_OP_VERTICAL}, // set minus
{U"\x2217",    MATHML_OP_INFIX, 4, 4, 0}, // asterisk operator
{U"\x2218",    MATHML_OP_INFIX, 4, 4, 0}, // &SmallCircle;
{U"\x2219",    MATHML_OP_INFIX, 4, 4, 0}, // bullet operator
{U"\x221A",   MATHML_OP_PREFIX, 1, 1, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL|MATHML_OP_MIRRORABLE}, // &Sqrt;
{U"\x221B",   MATHML_OP_PREFIX, 1, 1, 0}, // cube root
{U"\x221C",   MATHML_OP_PREFIX, 1, 1, 0}, // fourth root
{U"\x221D",    MATHML_OP_INFIX, 5, 5, 0}, // &Proportional;
{U"\x221F",    MATHML_OP_INFIX, 5, 5, 0}, // right angle
{U"\x2220",   MATHML_OP_PREFIX, 0, 0, 0}, // angle
{U"\x2221",   MATHML_OP_PREFIX, 0, 0, 0}, // measured angle
{U"\x2222",   MATHML_OP_PREFIX, 0, 0, 0}, // spherical angle
{U"\x2223",    MATHML_OP_INFIX, 5, 5, MATHML_OP_VERTICAL}, // divides
{U"\x2223",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // &VerticalBar;
{U"\x2223",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // &VerticalBar;
{U"\x2224",    MATHML_OP_INFIX, 5, 5, 0}, // &NotVerticalBar;
{U"\x2225",    MATHML_OP_INFIX, 5, 5, MATHML_OP_VERTICAL}, // parallel to
{U"\x2225",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // &DoubleVerticalBar;
{U"\x2225",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // &DoubleVerticalBar;
{U"\x2226",    MATHML_OP_INFIX, 5, 5, 0}, // &NotDoubleVerticalBar;
{U"\x2227",    MATHML_OP_INFIX, 4, 4, 0}, // &wedge;
{U"\x2228",    MATHML_OP_INFIX, 4, 4, 0}, // &vee;
{U"\x2229",    MATHML_OP_INFIX, 4, 4, 0}, // &cap;
{U"\x222A",    MATHML_OP_INFIX, 4, 4, 0}, // &cup;
{U"\x222B",   MATHML_OP_PREFIX, 0, 1, MATHML_OP_LARGEOP|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_INTEGRAL|MATHML_OP_MIRRORABLE}, // &Integral;
{U"\x222C",   MATHML_OP_PREFIX, 0, 1, MATHML_OP_LARGEOP|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_INTEGRAL|MATHML_OP_MIRRORABLE}, // double integral
{U"\x222D",   MATHML_OP_PREFIX, 0, 1, MATHML_OP_LARGEOP|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_INTEGRAL|MATHML_OP_MIRRORABLE}, // triple integral
{U"\x222E",   MATHML_OP_PREFIX, 0, 1, MATHML_OP_LARGEOP|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_INTEGRAL|MATHML_OP_MIRRORABLE}, // &ContourIntegral;
{U"\x222F",   MATHML_OP_PREFIX, 0, 1, MATHML_OP_LARGEOP|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_INTEGRAL|MATHML_OP_MIRRORABLE}, // &DoubleContourIntegral;
{U"\x2230",   MATHML_OP_PREFIX, 0, 1, MATHML_OP_LARGEOP|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_INTEGRAL|MATHML_OP_MIRRORABLE}, // volume integral
{U"\x2231",   MATHML_OP_PREFIX, 0, 1, MATHML_OP_LARGEOP|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_INTEGRAL}, // clockwise integral
{U"\x2232",   MATHML_OP_PREFIX, 0, 1, MATHML_OP_LARGEOP|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_INTEGRAL}, // &ClockwiseContourIntegral;
{U"\x2233",   MATHML_OP_PREFIX, 0, 1, MATHML_OP_LARGEOP|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_INTEGRAL}, // &CounterClockwiseContourIntegral;
{U"\x2234",    MATHML_OP_INFIX, 5, 5, 0}, // &Therefore;
{U"\x2235",    MATHML_OP_INFIX, 5, 5, 0}, // &Because;
{U"\x2236",    MATHML_OP_INFIX, 5, 5, 0}, // ratio
{U"\x2237",    MATHML_OP_INFIX, 5, 5, 0}, // &Colon; &Proportion;
{U"\x2238",    MATHML_OP_INFIX, 4, 4, 0}, // dot minus
{U"\x2239",    MATHML_OP_INFIX, 5, 5, 0}, // excess
{U"\x223A",    MATHML_OP_INFIX, 4, 4, 0}, // geometric proportion
{U"\x223B",    MATHML_OP_INFIX, 5, 5, 0}, // homothetic
{U"\x223C",    MATHML_OP_INFIX, 5, 5, 0}, // &Tilde;
{U"\x223D",    MATHML_OP_INFIX, 5, 5, 0}, // reversed tilde
{U"\x223D\x0331",    MATHML_OP_INFIX, 3, 3, 0}, // reversed tilde with underline
{U"\x223E",    MATHML_OP_INFIX, 5, 5, 0}, // inverted lazy s
{U"\x223F",    MATHML_OP_INFIX, 3, 3, 0}, // sine wave
{U"\x2240",    MATHML_OP_INFIX, 4, 4, 0}, // &VerticalTilde;
{U"\x2241",    MATHML_OP_INFIX, 5, 5, 0}, // &NotTilde;
{U"\x2242",    MATHML_OP_INFIX, 5, 5, 0}, // &EqualTilde;
{U"\x2242\x0338",    MATHML_OP_INFIX, 5, 5, 0}, // &NotEqualTilde;
{U"\x2243",    MATHML_OP_INFIX, 5, 5, 0}, // &TildeEqual;
{U"\x2244",    MATHML_OP_INFIX, 5, 5, 0}, // &NotTildeEqual;
{U"\x2245",    MATHML_OP_INFIX, 5, 5, 0}, // &TildeFullEqual;
{U"\x2246",    MATHML_OP_INFIX, 5, 5, 0}, // approximately but not actually equal to
{U"\x2247",    MATHML_OP_INFIX, 5, 5, 0}, // &NotTildeFullEqual;
{U"\x2248",    MATHML_OP_INFIX, 5, 5, 0}, // &TildeTilde;
{U"\x2249",    MATHML_OP_INFIX, 5, 5, 0}, // &NotTildeTilde;
{U"\x224A",    MATHML_OP_INFIX, 5, 5, 0}, // almost equal or equal to
{U"\x224B",    MATHML_OP_INFIX, 5, 5, 0}, // triple tilde
{U"\x224C",    MATHML_OP_INFIX, 5, 5, 0}, // all equal to
{U"\x224D",    MATHML_OP_INFIX, 5, 5, 0}, // &CupCap;
{U"\x224E",    MATHML_OP_INFIX, 5, 5, 0}, // &HumpDownHump;
{U"\x224E\x0338",    MATHML_OP_INFIX, 5, 5, 0}, // &NotHumpDownHump;
{U"\x224F",    MATHML_OP_INFIX, 5, 5, 0}, // &HumpEqual;
{U"\x224F\x0338",    MATHML_OP_INFIX, 5, 5, 0}, // &NotHumpEqual;
{U"\x2250",    MATHML_OP_INFIX, 5, 5, 0}, // &DotEqual;
{U"\x2251",    MATHML_OP_INFIX, 5, 5, 0}, // geometrically equal to
{U"\x2252",    MATHML_OP_INFIX, 5, 5, 0}, // approximately equal to or the image of
{U"\x2253",    MATHML_OP_INFIX, 5, 5, 0}, // image of or approximately equal to
{U"\x2254",    MATHML_OP_INFIX, 5, 5, 0}, // &Assign;
{U"\x2255",    MATHML_OP_INFIX, 5, 5, 0}, // equals colon
{U"\x2256",    MATHML_OP_INFIX, 5, 5, 0}, // ring in equal to
{U"\x2257",    MATHML_OP_INFIX, 5, 5, 0}, // ring equal to
{U"\x2258",    MATHML_OP_INFIX, 5, 5, 0}, // corresponds to
{U"\x2259",    MATHML_OP_INFIX, 5, 5, 0}, // estimates
{U"\x225A",    MATHML_OP_INFIX, 5, 5, 0}, // equiangular to
{U"\x225C",    MATHML_OP_INFIX, 5, 5, 0}, // delta equal to
{U"\x225D",    MATHML_OP_INFIX, 5, 5, 0}, // equal to by definition
{U"\x225E",    MATHML_OP_INFIX, 5, 5, 0}, // measured by
{U"\x225F",    MATHML_OP_INFIX, 5, 5, 0}, // questioned equal to
{U"\x2260",    MATHML_OP_INFIX, 5, 5, 0}, // &NotEqual;
{U"\x2261",    MATHML_OP_INFIX, 5, 5, 0}, // &Congruent;
{U"\x2262",    MATHML_OP_INFIX, 5, 5, 0}, // &NotCongruent;
{U"\x2263",    MATHML_OP_INFIX, 5, 5, 0}, // strictly equivalent to
{U"\x2264",    MATHML_OP_INFIX, 5, 5, 0}, // &le;
{U"\x2265",    MATHML_OP_INFIX, 5, 5, 0}, // &GreaterEqual;
{U"\x2266",    MATHML_OP_INFIX, 5, 5, 0}, // &LessFullEqual;
{U"\x2266\x0338",    MATHML_OP_INFIX, 5, 5, 0}, // &NotGreaterFullEqual;
{U"\x2267",    MATHML_OP_INFIX, 5, 5, 0}, // &GreaterFullEqual;
{U"\x2268",    MATHML_OP_INFIX, 5, 5, 0}, // less-than but not equal to
{U"\x2269",    MATHML_OP_INFIX, 5, 5, 0}, // greater-than but not equal to
{U"\x226A",    MATHML_OP_INFIX, 5, 5, 0}, // &NestedLessLess;
{U"\x226A\x0338",    MATHML_OP_INFIX, 5, 5, 0}, // &NotLessLess;
{U"\x226B",    MATHML_OP_INFIX, 5, 5, 0}, // &NestedGreaterGreater;
{U"\x226B\x0338",    MATHML_OP_INFIX, 5, 5, 0}, // &NotGreaterGreater;
{U"\x226C",    MATHML_OP_INFIX, 5, 5, 0}, // between
{U"\x226D",    MATHML_OP_INFIX, 5, 5, 0}, // &NotCupCap;
{U"\x226E",    MATHML_OP_INFIX, 5, 5, 0}, // &NotLess;
{U"\x226F",    MATHML_OP_INFIX, 5, 5, 0}, // &NotGreater;
{U"\x2270",    MATHML_OP_INFIX, 5, 5, 0}, // &NotLessEqual;
{U"\x2271",    MATHML_OP_INFIX, 5, 5, 0}, // &NotGreaterEqual;
{U"\x2272",    MATHML_OP_INFIX, 5, 5, 0}, // &LessTilde;
{U"\x2273",    MATHML_OP_INFIX, 5, 5, 0}, // &GreaterTilde;
{U"\x2274",    MATHML_OP_INFIX, 5, 5, 0}, // &NotLessTilde;
{U"\x2275",    MATHML_OP_INFIX, 5, 5, 0}, // &NotGreaterTilde;
{U"\x2276",    MATHML_OP_INFIX, 5, 5, 0}, // &LessGreater;
{U"\x2277",    MATHML_OP_INFIX, 5, 5, 0}, // &GreaterLess;
{U"\x2278",    MATHML_OP_INFIX, 5, 5, 0}, // &NotLessGreater;
{U"\x2279",    MATHML_OP_INFIX, 5, 5, 0}, // &NotGreaterLess;
{U"\x227A",    MATHML_OP_INFIX, 5, 5, 0}, // &Precedes;
{U"\x227B",    MATHML_OP_INFIX, 5, 5, 0}, // &Succeeds;
{U"\x227C",    MATHML_OP_INFIX, 5, 5, 0}, // &PrecedesSlantEqual;
{U"\x227D",    MATHML_OP_INFIX, 5, 5, 0}, // &SucceedsSlantEqual;
{U"\x227E",    MATHML_OP_INFIX, 5, 5, 0}, // &PrecedesTilde;
{U"\x227F",    MATHML_OP_INFIX, 5, 5, 0}, // &SucceedsTilde;
{U"\x227F\x0338",    MATHML_OP_INFIX, 5, 5, 0}, // &NotSucceedsTilde;
{U"\x2280",    MATHML_OP_INFIX, 5, 5, 0}, // &NotPrecedes;
{U"\x2281",    MATHML_OP_INFIX, 5, 5, 0}, // &NotSucceeds;
{U"\x2282",    MATHML_OP_INFIX, 5, 5, 0}, // &subset;
{U"\x2282\x020D2",    MATHML_OP_INFIX, 5, 5, 0}, // &NotSubset;
{U"\x2282\x20D2",    MATHML_OP_INFIX, 5, 5, 0}, // subset of with vertical line
{U"\x2283",    MATHML_OP_INFIX, 5, 5, 0}, // &Superset;
{U"\x2283\x020D2",    MATHML_OP_INFIX, 5, 5, 0}, // &NotSuperset;
{U"\x2283\x20D2",    MATHML_OP_INFIX, 5, 5, 0}, // superset of with vertical line
{U"\x2284",    MATHML_OP_INFIX, 5, 5, 0}, // &nsub;
{U"\x2285",    MATHML_OP_INFIX, 5, 5, 0}, // &nsup;
{U"\x2286",    MATHML_OP_INFIX, 5, 5, 0}, // &SubsetEqual;
{U"\x2287",    MATHML_OP_INFIX, 5, 5, 0}, // &SupersetEqual;
{U"\x2288",    MATHML_OP_INFIX, 5, 5, 0}, // &NotSubsetEqual;
{U"\x2289",    MATHML_OP_INFIX, 5, 5, 0}, // &NotSupersetEqual;
{U"\x228A",    MATHML_OP_INFIX, 5, 5, 0}, // &subsetneq; &subne;
{U"\x228B",    MATHML_OP_INFIX, 5, 5, 0}, // superset of with not equal to
{U"\x228C",    MATHML_OP_INFIX, 4, 4, 0}, // multiset
{U"\x228D",    MATHML_OP_INFIX, 4, 4, 0}, // multiset multiplication
{U"\x228E",    MATHML_OP_INFIX, 4, 4, MATHML_OP_VERTICAL}, // &UnionPlus;
{U"\x228E",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_MOVABLELIMITS|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // &UnionPlus;
{U"\x228F",    MATHML_OP_INFIX, 5, 5, 0}, // &SquareSubset;
{U"\x228F\x0338",    MATHML_OP_INFIX, 5, 5, 0}, // &NotSquareSubset;
{U"\x2290",    MATHML_OP_INFIX, 5, 5, 0}, // &SquareSuperset;
{U"\x2290\x0338",    MATHML_OP_INFIX, 5, 5, 0}, // &NotSquareSuperset;
{U"\x2291",    MATHML_OP_INFIX, 5, 5, 0}, // &SquareSubsetEqual;
{U"\x2292",    MATHML_OP_INFIX, 5, 5, 0}, // &SquareSupersetEqual;
{U"\x2293",    MATHML_OP_INFIX, 4, 4, MATHML_OP_VERTICAL}, // &SquareIntersection;
{U"\x2294",    MATHML_OP_INFIX, 4, 4, MATHML_OP_VERTICAL}, // &SquareUnion;
{U"\x2295",    MATHML_OP_INFIX, 4, 4, 0}, // &CirclePlus;
{U"\x2295",   MATHML_OP_PREFIX, 0, 3, MATHML_OP_LARGEOP|MATHML_OP_MOVABLELIMITS|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // &CirclePlus;
{U"\x2296",    MATHML_OP_INFIX, 4, 4, 0}, // &CircleMinus;
{U"\x2296",   MATHML_OP_PREFIX, 0, 3, MATHML_OP_LARGEOP|MATHML_OP_MOVABLELIMITS|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // &CircleMinus;
{U"\x2297",    MATHML_OP_INFIX, 4, 4, 0}, // &CircleTimes;
{U"\x2297",   MATHML_OP_PREFIX, 0, 3, MATHML_OP_LARGEOP|MATHML_OP_MOVABLELIMITS|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // &CircleTimes;
{U"\x2298",    MATHML_OP_INFIX, 4, 4, 0}, // circled division slash
{U"\x2299",    MATHML_OP_INFIX, 4, 4, 0}, // &CircleDot;
{U"\x2299",   MATHML_OP_PREFIX, 0, 3, MATHML_OP_LARGEOP|MATHML_OP_MOVABLELIMITS|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // &CircleDot;
{U"\x229A",    MATHML_OP_INFIX, 4, 4, 0}, // circled ring operator
{U"\x229B",    MATHML_OP_INFIX, 4, 4, 0}, // circled asterisk operator
{U"\x229C",    MATHML_OP_INFIX, 4, 4, 0}, // circled equals
{U"\x229D",    MATHML_OP_INFIX, 4, 4, 0}, // circled dash
{U"\x229E",    MATHML_OP_INFIX, 4, 4, 0}, // squared plus
{U"\x229F",    MATHML_OP_INFIX, 4, 4, 0}, // squared minus
{U"\x22A0",    MATHML_OP_INFIX, 4, 4, 0}, // squared times
{U"\x22A1",    MATHML_OP_INFIX, 4, 4, 0}, // squared dot operator
{U"\x22A2",    MATHML_OP_INFIX, 5, 5, 0}, // &RightTee;
{U"\x22A3",    MATHML_OP_INFIX, 5, 5, 0}, // &LeftTee;
{U"\x22A4",    MATHML_OP_INFIX, 5, 5, 0}, // &DownTee;
{U"\x22A5",    MATHML_OP_INFIX, 5, 5, 0}, // &UpTee;
{U"\x22A6",    MATHML_OP_INFIX, 5, 5, 0}, // assertion
{U"\x22A7",    MATHML_OP_INFIX, 5, 5, 0}, // models
{U"\x22A8",    MATHML_OP_INFIX, 5, 5, 0}, // &DoubleRightTee;
{U"\x22A9",    MATHML_OP_INFIX, 5, 5, 0}, // forces
{U"\x22AA",    MATHML_OP_INFIX, 5, 5, 0}, // triple vertical bar right turnstile
{U"\x22AB",    MATHML_OP_INFIX, 5, 5, 0}, // double vertical bar double right turnstile
{U"\x22AC",    MATHML_OP_INFIX, 5, 5, 0}, // does not prove
{U"\x22AD",    MATHML_OP_INFIX, 5, 5, 0}, // not true
{U"\x22AE",    MATHML_OP_INFIX, 5, 5, 0}, // does not force
{U"\x22AF",    MATHML_OP_INFIX, 5, 5, 0}, // negated double vertical bar double right turnstile
{U"\x22B0",    MATHML_OP_INFIX, 5, 5, 0}, // precedes under relation
{U"\x22B1",    MATHML_OP_INFIX, 5, 5, 0}, // succeeds under relation
{U"\x22B2",    MATHML_OP_INFIX, 5, 5, 0}, // &LeftTriangle;
{U"\x22B3",    MATHML_OP_INFIX, 5, 5, 0}, // &RightTriangle;
{U"\x22B4",    MATHML_OP_INFIX, 5, 5, 0}, // &LeftTriangleEqual;
{U"\x22B5",    MATHML_OP_INFIX, 5, 5, 0}, // &RightTriangleEqual;
{U"\x22B6",    MATHML_OP_INFIX, 5, 5, 0}, // original of
{U"\x22B7",    MATHML_OP_INFIX, 5, 5, 0}, // image of
{U"\x22B8",    MATHML_OP_INFIX, 5, 5, 0}, // multimap
{U"\x22B9",    MATHML_OP_INFIX, 5, 5, 0}, // hermitian conjugate matrix
{U"\x22BA",    MATHML_OP_INFIX, 4, 4, 0}, // intercalate
{U"\x22BB",    MATHML_OP_INFIX, 4, 4, 0}, // xor
{U"\x22BC",    MATHML_OP_INFIX, 4, 4, 0}, // nand
{U"\x22BD",    MATHML_OP_INFIX, 4, 4, 0}, // nor
{U"\x22BE",    MATHML_OP_INFIX, 3, 3, 0}, // right angle with arc
{U"\x22BF",    MATHML_OP_INFIX, 3, 3, 0}, // right triangle
{U"\x22C0",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_MOVABLELIMITS|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // &Wedge;
{U"\x22C1",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_MOVABLELIMITS|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // &Vee;
{U"\x22C2",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_MOVABLELIMITS|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // &Intersection;
{U"\x22C3",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_MOVABLELIMITS|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // &Union;
{U"\x22C4",    MATHML_OP_INFIX, 4, 4, 0}, // &Diamond;
{U"\x22C5",    MATHML_OP_INFIX, 4, 4, 0}, // &cdot;
{U"\x22C6",    MATHML_OP_INFIX, 4, 4, 0}, // &Star;
{U"\x22C7",    MATHML_OP_INFIX, 4, 4, 0}, // division times
{U"\x22C8",    MATHML_OP_INFIX, 5, 5, 0}, // bowtie
{U"\x22C9",    MATHML_OP_INFIX, 4, 4, 0}, // left normal factor semidirect product
{U"\x22CA",    MATHML_OP_INFIX, 4, 4, 0}, // right normal factor semidirect product
{U"\x22CB",    MATHML_OP_INFIX, 4, 4, 0}, // left semidirect product
{U"\x22CC",    MATHML_OP_INFIX, 4, 4, 0}, // right semidirect product
{U"\x22CD",    MATHML_OP_INFIX, 5, 5, 0}, // reversed tilde equals
{U"\x22CE",    MATHML_OP_INFIX, 4, 4, 0}, // curly logical or
{U"\x22CF",    MATHML_OP_INFIX, 4, 4, 0}, // curly logical and
{U"\x22D0",    MATHML_OP_INFIX, 5, 5, 0}, // &Subset;
{U"\x22D1",    MATHML_OP_INFIX, 5, 5, 0}, // double superset
{U"\x22D2",    MATHML_OP_INFIX, 4, 4, 0}, // &Cap;
{U"\x22D3",    MATHML_OP_INFIX, 4, 4, 0}, // &Cup;
{U"\x22D4",    MATHML_OP_INFIX, 5, 5, 0}, // pitchfork
{U"\x22D5",    MATHML_OP_INFIX, 5, 5, 0}, // equal and parallel to
{U"\x22D6",    MATHML_OP_INFIX, 5, 5, 0}, // less-than with dot
{U"\x22D7",    MATHML_OP_INFIX, 5, 5, 0}, // greater-than with dot
{U"\x22D8",    MATHML_OP_INFIX, 5, 5, 0}, // very much less-than
{U"\x22D9",    MATHML_OP_INFIX, 5, 5, 0}, // very much greater-than
{U"\x22DA",    MATHML_OP_INFIX, 5, 5, 0}, // &LessEqualGreater;
{U"\x22DB",    MATHML_OP_INFIX, 5, 5, 0}, // &GreaterEqualLess;
{U"\x22DC",    MATHML_OP_INFIX, 5, 5, 0}, // equal to or less-than
{U"\x22DD",    MATHML_OP_INFIX, 5, 5, 0}, // equal to or greater-than
{U"\x22DE",    MATHML_OP_INFIX, 5, 5, 0}, // equal to or precedes
{U"\x22DF",    MATHML_OP_INFIX, 5, 5, 0}, // equal to or succeeds
{U"\x22E0",    MATHML_OP_INFIX, 5, 5, 0}, // &NotPrecedesSlantEqual;
{U"\x22E1",    MATHML_OP_INFIX, 5, 5, 0}, // &NotSucceedsSlantEqual;
{U"\x22E2",    MATHML_OP_INFIX, 5, 5, 0}, // &NotSquareSubsetEqual;
{U"\x22E3",    MATHML_OP_INFIX, 5, 5, 0}, // &NotSquareSupersetEqual;
{U"\x22E4",    MATHML_OP_INFIX, 5, 5, 0}, // square image of or not equal to
{U"\x22E5",    MATHML_OP_INFIX, 5, 5, 0}, // square original of or not equal to
{U"\x22E6",    MATHML_OP_INFIX, 5, 5, 0}, // less-than but not equivalent to
{U"\x22E7",    MATHML_OP_INFIX, 5, 5, 0}, // greater-than but not equivalent to
{U"\x22E8",    MATHML_OP_INFIX, 5, 5, 0}, // precedes but not equivalent to
{U"\x22E9",    MATHML_OP_INFIX, 5, 5, 0}, // succeeds but not equivalent to
{U"\x22EA",    MATHML_OP_INFIX, 5, 5, 0}, // &NotLeftTriangle;
{U"\x22EB",    MATHML_OP_INFIX, 5, 5, 0}, // &NotRightTriangle;
{U"\x22EC",    MATHML_OP_INFIX, 5, 5, 0}, // &NotLeftTriangleEqual;
{U"\x22ED",    MATHML_OP_INFIX, 5, 5, 0}, // &NotRightTriangleEqual;
{U"\x22EE",    MATHML_OP_INFIX, 5, 5, 0}, // vertical ellipsis
{U"\x22EF",    MATHML_OP_INFIX, 0, 0, 0}, // midline horizontal ellipsis
{U"\x22F0",    MATHML_OP_INFIX, 5, 5, 0}, // up right diagonal ellipsis
{U"\x22F1",    MATHML_OP_INFIX, 5, 5, 0}, // down right diagonal ellipsis
{U"\x22F2",    MATHML_OP_INFIX, 5, 5, 0}, // element of with long horizontal stroke
{U"\x22F3",    MATHML_OP_INFIX, 5, 5, 0}, // element of with vertical bar at end of horizontal stroke
{U"\x22F4",    MATHML_OP_INFIX, 5, 5, 0}, // small element of with vertical bar at end of horizontal stroke
{U"\x22F5",    MATHML_OP_INFIX, 5, 5, 0}, // element of with dot above
{U"\x22F6",    MATHML_OP_INFIX, 5, 5, 0}, // element of with overbar
{U"\x22F7",    MATHML_OP_INFIX, 5, 5, 0}, // small element of with overbar
{U"\x22F8",    MATHML_OP_INFIX, 5, 5, 0}, // element of with underbar
{U"\x22F9",    MATHML_OP_INFIX, 5, 5, 0}, // element of with two horizontal strokes
{U"\x22FA",    MATHML_OP_INFIX, 5, 5, 0}, // contains with long horizontal stroke
{U"\x22FB",    MATHML_OP_INFIX, 5, 5, 0}, // contains with vertical bar at end of horizontal stroke
{U"\x22FC",    MATHML_OP_INFIX, 5, 5, 0}, // small contains with vertical bar at end of horizontal stroke
{U"\x22FD",    MATHML_OP_INFIX, 5, 5, 0}, // contains with overbar
{U"\x22FE",    MATHML_OP_INFIX, 5, 5, 0}, // small contains with overbar
{U"\x22FF",    MATHML_OP_INFIX, 5, 5, 0}, // z notation bag membership
{U"\x2308",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // &LeftCeiling;
{U"\x2309",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // &RightCeiling;
{U"\x230A",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // &LeftFloor;
{U"\x230B",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // &RightFloor;
{U"\x23B0",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // &lmoustache; &lmoust;
{U"\x23B1",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // &rmoustache; &rmoust;
{U"\x23B4",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &OverBracket;
{U"\x23B5",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &UnderBracket;
{U"\x23DC",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &OverParenthesis; (Unicode)
{U"\x23DD",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &UnderParenthesis; (Unicode)
{U"\x23DE",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &OverBrace; (Unicode)
{U"\x23DF",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &UnderBrace; (Unicode)
{U"\x23E0",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // top tortoise shell bracket
{U"\x23E1",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // bottom tortoise shell bracket
{U"\x2500",    MATHML_OP_INFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_HORIZONTAL}, // &HorizontalLine;
{U"\x25A0",    MATHML_OP_INFIX, 3, 3, 0}, // black square
{U"\x25A1",    MATHML_OP_INFIX, 3, 3, 0}, // white square
{U"\x25A1",   MATHML_OP_PREFIX, 0, 2, 0}, // &Square;
{U"\x25AA",    MATHML_OP_INFIX, 3, 3, 0}, // black small square
{U"\x25AB",    MATHML_OP_INFIX, 3, 3, 0}, // white small square
{U"\x25AD",    MATHML_OP_INFIX, 3, 3, 0}, // white rectangle
{U"\x25AE",    MATHML_OP_INFIX, 3, 3, 0}, // black vertical rectangle
{U"\x25AF",    MATHML_OP_INFIX, 3, 3, 0}, // white vertical rectangle
{U"\x25B0",    MATHML_OP_INFIX, 3, 3, 0}, // black parallelogram
{U"\x25B1",    MATHML_OP_INFIX, 3, 3, 0}, // white parallelogram
{U"\x25B2",    MATHML_OP_INFIX, 4, 4, 0}, // black up-pointing triangle
{U"\x25B3",    MATHML_OP_INFIX, 4, 4, 0}, // white up-pointing triangle
{U"\x25B4",    MATHML_OP_INFIX, 4, 4, 0}, // black up-pointing small triangle
{U"\x25B5",    MATHML_OP_INFIX, 4, 4, 0}, // white up-pointing small triangle
{U"\x25B6",    MATHML_OP_INFIX, 4, 4, 0}, // black right-pointing triangle
{U"\x25B7",    MATHML_OP_INFIX, 4, 4, 0}, // white right-pointing triangle
{U"\x25B8",    MATHML_OP_INFIX, 4, 4, 0}, // black right-pointing small triangle
{U"\x25B9",    MATHML_OP_INFIX, 4, 4, 0}, // white right-pointing small triangle
{U"\x25BC",    MATHML_OP_INFIX, 4, 4, 0}, // black down-pointing triangle
{U"\x25BD",    MATHML_OP_INFIX, 4, 4, 0}, // white down-pointing triangle
{U"\x25BE",    MATHML_OP_INFIX, 4, 4, 0}, // black down-pointing small triangle
{U"\x25BF",    MATHML_OP_INFIX, 4, 4, 0}, // white down-pointing small triangle
{U"\x25C0",    MATHML_OP_INFIX, 4, 4, 0}, // black left-pointing triangle
{U"\x25C1",    MATHML_OP_INFIX, 4, 4, 0}, // white left-pointing triangle
{U"\x25C2",    MATHML_OP_INFIX, 4, 4, 0}, // black left-pointing small triangle
{U"\x25C3",    MATHML_OP_INFIX, 4, 4, 0}, // white left-pointing small triangle
{U"\x25C4",    MATHML_OP_INFIX, 4, 4, 0}, // black left-pointing pointer
{U"\x25C5",    MATHML_OP_INFIX, 4, 4, 0}, // white left-pointing pointer
{U"\x25C6",    MATHML_OP_INFIX, 4, 4, 0}, // black diamond
{U"\x25C7",    MATHML_OP_INFIX, 4, 4, 0}, // white diamond
{U"\x25C8",    MATHML_OP_INFIX, 4, 4, 0}, // white diamond containing black small diamond
{U"\x25C9",    MATHML_OP_INFIX, 4, 4, 0}, // fisheye
{U"\x25CC",    MATHML_OP_INFIX, 4, 4, 0}, // dotted circle
{U"\x25CD",    MATHML_OP_INFIX, 4, 4, 0}, // circle with vertical fill
{U"\x25CE",    MATHML_OP_INFIX, 4, 4, 0}, // bullseye
{U"\x25CF",    MATHML_OP_INFIX, 4, 4, 0}, // black circle
{U"\x25D6",    MATHML_OP_INFIX, 4, 4, 0}, // left half black circle
{U"\x25D7",    MATHML_OP_INFIX, 4, 4, 0}, // right half black circle
{U"\x25E6",    MATHML_OP_INFIX, 4, 4, 0}, // white bullet
{U"\x2606",    MATHML_OP_INFIX, 3, 3, 0}, // &star;
{U"\x266D",  MATHML_OP_POSTFIX, 0, 2, 0}, // music flat sign
{U"\x266E",  MATHML_OP_POSTFIX, 0, 2, 0}, // music natural sign
{U"\x266F",  MATHML_OP_POSTFIX, 0, 2, 0}, // music sharp sign
{U"\x2758",    MATHML_OP_INFIX, 5, 5, MATHML_OP_VERTICAL}, // light vertical bar
{U"\x2772",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // light left tortoise shell bracket ornament
{U"\x2773",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // light right tortoise shell bracket ornament
{U"\x27E6",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // &LeftDoubleBracket;
{U"\x27E7",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // &RightDoubleBracket;
{U"\x27E8",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // &LeftAngleBracket;
{U"\x27E9",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // &RightAngleBracket;
{U"\x27EA",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // mathematical left double angle bracket
{U"\x27EB",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // mathematical right double angle bracket
{U"\x27EC",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // mathematical left white tortoise shell bracket
{U"\x27ED",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // mathematical right white tortoise shell bracket
{U"\x27EE",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // mathematical left flattened parenthesis
{U"\x27EF",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // mathematical right flattened parenthesis
{U"\x27F0",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // upwards quadruple arrow
{U"\x27F1",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // downwards quadruple arrow
{U"\x27F5",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &LongLeftArrow;
{U"\x27F6",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &LongRightArrow;
{U"\x27F7",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &LongLeftRightArrow;
{U"\x27F8",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &DoubleLongLeftArrow;
{U"\x27F9",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &DoubleLongRightArrow;
{U"\x27FA",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &DoubleLongLeftRightArrow;
{U"\x27FB",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // long leftwards arrow from bar
{U"\x27FC",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // long rightwards arrow from bar
{U"\x27FD",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // long leftwards double arrow from bar
{U"\x27FE",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // long rightwards double arrow from bar
{U"\x27FF",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // long rightwards squiggle arrow
{U"\x2900",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // rightwards two-headed arrow with vertical stroke
{U"\x2901",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // rightwards two-headed arrow with double vertical stroke
{U"\x2902",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // leftwards double arrow with vertical stroke
{U"\x2903",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // rightwards double arrow with vertical stroke
{U"\x2904",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // left right double arrow with vertical stroke
{U"\x2905",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // rightwards two-headed arrow from bar
{U"\x2906",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // leftwards double arrow from bar
{U"\x2907",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // rightwards double arrow from bar
{U"\x2908",    MATHML_OP_INFIX, 5, 5, 0}, // downwards arrow with horizontal stroke
{U"\x2909",    MATHML_OP_INFIX, 5, 5, 0}, // upwards arrow with horizontal stroke
{U"\x290A",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // upwards triple arrow
{U"\x290B",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // downwards triple arrow
{U"\x290C",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // leftwards double dash arrow
{U"\x290D",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // rightwards double dash arrow
{U"\x290E",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // leftwards triple dash arrow
{U"\x290F",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // rightwards triple dash arrow
{U"\x2910",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // rightwards two-headed triple dash arrow
{U"\x2911",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // rightwards arrow with dotted stem
{U"\x2912",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &UpArrowBar;
{U"\x2913",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &DownArrowBar;
{U"\x2914",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // rightwards arrow with tail with vertical stroke
{U"\x2915",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // rightwards arrow with tail with double vertical stroke
{U"\x2916",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // rightwards two-headed arrow with tail
{U"\x2917",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // rightwards two-headed arrow with tail with vertical stroke
{U"\x2918",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // rightwards two-headed arrow with tail with double vertical stroke
{U"\x2919",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // leftwards arrow-tail
{U"\x291A",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // rightwards arrow-tail
{U"\x291B",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // leftwards double arrow-tail
{U"\x291C",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // rightwards double arrow-tail
{U"\x291D",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // leftwards arrow to black diamond
{U"\x291E",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // rightwards arrow to black diamond
{U"\x291F",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // leftwards arrow from bar to black diamond
{U"\x2920",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // rightwards arrow from bar to black diamond
{U"\x2923",    MATHML_OP_INFIX, 5, 5, 0}, // north west arrow with hook
{U"\x2924",    MATHML_OP_INFIX, 5, 5, 0}, // north east arrow with hook
{U"\x2925",    MATHML_OP_INFIX, 5, 5, 0}, // south east arrow with hook
{U"\x2926",    MATHML_OP_INFIX, 5, 5, 0}, // south west arrow with hook
{U"\x2927",    MATHML_OP_INFIX, 5, 5, 0}, // north west arrow and north east arrow
{U"\x2928",    MATHML_OP_INFIX, 5, 5, 0}, // north east arrow and south east arrow
{U"\x2929",    MATHML_OP_INFIX, 5, 5, 0}, // south east arrow and south west arrow
{U"\x292A",    MATHML_OP_INFIX, 5, 5, 0}, // south west arrow and north west arrow
{U"\x292B",    MATHML_OP_INFIX, 5, 5, 0}, // rising diagonal crossing falling diagonal
{U"\x292C",    MATHML_OP_INFIX, 5, 5, 0}, // falling diagonal crossing rising diagonal
{U"\x292D",    MATHML_OP_INFIX, 5, 5, 0}, // south east arrow crossing north east arrow
{U"\x292E",    MATHML_OP_INFIX, 5, 5, 0}, // north east arrow crossing south east arrow
{U"\x292F",    MATHML_OP_INFIX, 5, 5, 0}, // falling diagonal crossing north east arrow
{U"\x2930",    MATHML_OP_INFIX, 5, 5, 0}, // rising diagonal crossing south east arrow
{U"\x2931",    MATHML_OP_INFIX, 5, 5, 0}, // north east arrow crossing north west arrow
{U"\x2932",    MATHML_OP_INFIX, 5, 5, 0}, // north west arrow crossing north east arrow
{U"\x2933",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // wave arrow pointing directly right
{U"\x2934",    MATHML_OP_INFIX, 5, 5, 0}, // arrow pointing rightwards then curving upwards
{U"\x2935",    MATHML_OP_INFIX, 5, 5, 0}, // arrow pointing rightwards then curving downwards
{U"\x2936",    MATHML_OP_INFIX, 5, 5, 0}, // arrow pointing downwards then curving leftwards
{U"\x2937",    MATHML_OP_INFIX, 5, 5, 0}, // arrow pointing downwards then curving rightwards
{U"\x2938",    MATHML_OP_INFIX, 5, 5, 0}, // right-side arc clockwise arrow
{U"\x2939",    MATHML_OP_INFIX, 5, 5, 0}, // left-side arc anticlockwise arrow
{U"\x293A",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // top arc anticlockwise arrow
{U"\x293B",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // bottom arc anticlockwise arrow
{U"\x293C",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // top arc clockwise arrow with minus
{U"\x293D",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // top arc anticlockwise arrow with plus
{U"\x293E",    MATHML_OP_INFIX, 5, 5, 0}, // lower right semicircular clockwise arrow
{U"\x293F",    MATHML_OP_INFIX, 5, 5, 0}, // lower left semicircular anticlockwise arrow
{U"\x2940",    MATHML_OP_INFIX, 5, 5, 0}, // anticlockwise closed circle arrow
{U"\x2941",    MATHML_OP_INFIX, 5, 5, 0}, // clockwise closed circle arrow
{U"\x2942",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // rightwards arrow above short leftwards arrow
{U"\x2943",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // leftwards arrow above short rightwards arrow
{U"\x2944",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // short rightwards arrow above leftwards arrow
{U"\x2945",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // rightwards arrow with plus below
{U"\x2946",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // leftwards arrow with plus below
{U"\x2947",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // rightwards arrow through x
{U"\x2948",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // left right arrow through small circle
{U"\x2949",    MATHML_OP_INFIX, 5, 5, 0}, // upwards two-headed arrow from small circle
{U"\x294A",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // left barb up right barb down harpoon
{U"\x294B",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // left barb down right barb up harpoon
{U"\x294C",    MATHML_OP_INFIX, 5, 5, 0}, // up barb right down barb left harpoon
{U"\x294D",    MATHML_OP_INFIX, 5, 5, 0}, // up barb left down barb right harpoon
{U"\x294E",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &LeftRightVector;
{U"\x294F",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &RightUpDownVector;
{U"\x2950",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &DownLeftRightVector;
{U"\x2951",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &LeftUpDownVector;
{U"\x2952",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &LeftVectorBar;
{U"\x2953",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &RightVectorBar;
{U"\x2954",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &RightUpVectorBar;
{U"\x2955",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &RightDownVectorBar;
{U"\x2956",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_HORIZONTAL}, // &DownLeftVectorBar;
{U"\x2957",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_HORIZONTAL}, // &DownRightVectorBar;
{U"\x2958",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &LeftUpVectorBar;
{U"\x2959",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &LeftDownVectorBar;
{U"\x295A",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &LeftTeeVector;
{U"\x295B",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &RightTeeVector;
{U"\x295C",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &RightUpTeeVector;
{U"\x295D",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &RightDownTeeVector;
{U"\x295E",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &DownLeftTeeVector;
{U"\x295F",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &DownRightTeeVector;
{U"\x2960",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &LeftUpTeeVector;
{U"\x2961",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &LeftDownTeeVector;
{U"\x2962",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // leftwards harpoon with barb up above leftwards harpoon with barb down
{U"\x2963",    MATHML_OP_INFIX, 5, 5, 0}, // upwards harpoon with barb left beside upwards harpoon with barb right
{U"\x2964",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // rightwards harpoon with barb up above rightwards harpoon with barb down
{U"\x2965",    MATHML_OP_INFIX, 5, 5, 0}, // downwards harpoon with barb left beside downwards harpoon with barb right
{U"\x2966",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // leftwards harpoon with barb up above rightwards harpoon with barb up
{U"\x2967",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // leftwards harpoon with barb down above rightwards harpoon with barb down
{U"\x2968",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // rightwards harpoon with barb up above leftwards harpoon with barb up
{U"\x2969",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // rightwards harpoon with barb down above leftwards harpoon with barb down
{U"\x296A",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // leftwards harpoon with barb up above long dash
{U"\x296B",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // leftwards harpoon with barb down below long dash
{U"\x296C",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // rightwards harpoon with barb up above long dash
{U"\x296D",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // rightwards harpoon with barb down below long dash
{U"\x296E",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &UpEquilibrium;
{U"\x296F",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_VERTICAL}, // &ReverseUpEquilibrium;
{U"\x2970",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // &RoundImplies;
{U"\x2971",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // equals sign above rightwards arrow
{U"\x2972",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // tilde operator above rightwards arrow
{U"\x2973",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // leftwards arrow above tilde operator
{U"\x2974",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // rightwards arrow above tilde operator
{U"\x2975",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // rightwards arrow above almost equal to
{U"\x2976",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // less-than above leftwards arrow
{U"\x2977",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // leftwards arrow through less-than
{U"\x2978",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // greater-than above rightwards arrow
{U"\x2979",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // subset above rightwards arrow
{U"\x297A",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // leftwards arrow through subset
{U"\x297B",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // superset above leftwards arrow
{U"\x297C",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // left fish tail
{U"\x297D",    MATHML_OP_INFIX, 5, 5, MATHML_OP_ACCENT}, // right fish tail
{U"\x297E",    MATHML_OP_INFIX, 5, 5, 0}, // up fish tail
{U"\x297F",    MATHML_OP_INFIX, 5, 5, 0}, // down fish tail
{U"\x2980",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_VERTICAL}, // triple direction:vertical bar delimiter
{U"\x2980",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_VERTICAL}, // triple direction:vertical bar delimiter
{U"\x2981",    MATHML_OP_INFIX, 3, 3, 0}, // z notation spot
{U"\x2982",    MATHML_OP_INFIX, 3, 3, 0}, // z notation type colon
{U"\x2983",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // left white curly bracket
{U"\x2984",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // right white curly bracket
{U"\x2985",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // left white parenthesis
{U"\x2986",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // right white parenthesis
{U"\x2987",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // z notation left image bracket
{U"\x2988",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // z notation right image bracket
{U"\x2989",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // z notation left binding bracket
{U"\x298A",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // z notation right binding bracket
{U"\x298B",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // left square bracket with underbar
{U"\x298C",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // right square bracket with underbar
{U"\x298D",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // left square bracket with tick in top corner
{U"\x298E",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // right square bracket with tick in bottom corner
{U"\x298F",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // left square bracket with tick in bottom corner
{U"\x2990",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // right square bracket with tick in top corner
{U"\x2991",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // left angle bracket with dot
{U"\x2992",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // right angle bracket with dot
{U"\x2993",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // left arc less-than bracket
{U"\x2994",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // right arc greater-than bracket
{U"\x2995",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // double left arc greater-than bracket
{U"\x2996",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // double right arc less-than bracket
{U"\x2997",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // left black tortoise shell bracket
{U"\x2998",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // right black tortoise shell bracket
{U"\x2999",    MATHML_OP_INFIX, 3, 3, 0}, // dotted fence
{U"\x299A",    MATHML_OP_INFIX, 3, 3, 0}, // vertical zigzag line
{U"\x299B",    MATHML_OP_INFIX, 3, 3, 0}, // measured angle opening left
{U"\x299C",    MATHML_OP_INFIX, 3, 3, 0}, // right angle variant with square
{U"\x299D",    MATHML_OP_INFIX, 3, 3, 0}, // measured right angle with dot
{U"\x299E",    MATHML_OP_INFIX, 3, 3, 0}, // angle with s inside
{U"\x299F",    MATHML_OP_INFIX, 3, 3, 0}, // acute angle
{U"\x29A0",    MATHML_OP_INFIX, 3, 3, 0}, // spherical angle opening left
{U"\x29A1",    MATHML_OP_INFIX, 3, 3, 0}, // spherical angle opening up
{U"\x29A2",    MATHML_OP_INFIX, 3, 3, 0}, // turned angle
{U"\x29A3",    MATHML_OP_INFIX, 3, 3, 0}, // reversed angle
{U"\x29A4",    MATHML_OP_INFIX, 3, 3, 0}, // angle with underbar
{U"\x29A5",    MATHML_OP_INFIX, 3, 3, 0}, // reversed angle with underbar
{U"\x29A6",    MATHML_OP_INFIX, 3, 3, 0}, // oblique angle opening up
{U"\x29A7",    MATHML_OP_INFIX, 3, 3, 0}, // oblique angle opening down
{U"\x29A8",    MATHML_OP_INFIX, 3, 3, 0}, // measured angle with open arm ending in arrow pointing up and right
{U"\x29A9",    MATHML_OP_INFIX, 3, 3, 0}, // measured angle with open arm ending in arrow pointing up and left
{U"\x29AA",    MATHML_OP_INFIX, 3, 3, 0}, // measured angle with open arm ending in arrow pointing down and right
{U"\x29AB",    MATHML_OP_INFIX, 3, 3, 0}, // measured angle with open arm ending in arrow pointing down and left
{U"\x29AC",    MATHML_OP_INFIX, 3, 3, 0}, // measured angle with open arm ending in arrow pointing right and up
{U"\x29AD",    MATHML_OP_INFIX, 3, 3, 0}, // measured angle with open arm ending in arrow pointing left and up
{U"\x29AE",    MATHML_OP_INFIX, 3, 3, 0}, // measured angle with open arm ending in arrow pointing right and down
{U"\x29AF",    MATHML_OP_INFIX, 3, 3, 0}, // measured angle with open arm ending in arrow pointing left and down
{U"\x29B0",    MATHML_OP_INFIX, 3, 3, 0}, // reversed empty set
{U"\x29B1",    MATHML_OP_INFIX, 3, 3, 0}, // empty set with overbar
{U"\x29B2",    MATHML_OP_INFIX, 3, 3, 0}, // empty set with small circle above
{U"\x29B3",    MATHML_OP_INFIX, 3, 3, 0}, // empty set with right arrow above
{U"\x29B4",    MATHML_OP_INFIX, 3, 3, 0}, // empty set with left arrow above
{U"\x29B5",    MATHML_OP_INFIX, 3, 3, 0}, // circle with horizontal bar
{U"\x29B6",    MATHML_OP_INFIX, 4, 4, 0}, // circled vertical bar
{U"\x29B7",    MATHML_OP_INFIX, 4, 4, 0}, // circled parallel
{U"\x29B8",    MATHML_OP_INFIX, 4, 4, 0}, // circled reverse solidus
{U"\x29B9",    MATHML_OP_INFIX, 4, 4, 0}, // circled perpendicular
{U"\x29BA",    MATHML_OP_INFIX, 4, 4, 0}, // circle divided by horizontal bar and top half divided by vertical bar
{U"\x29BB",    MATHML_OP_INFIX, 4, 4, 0}, // circle with superimposed x
{U"\x29BC",    MATHML_OP_INFIX, 4, 4, 0}, // circled anticlockwise-rotated division sign
{U"\x29BD",    MATHML_OP_INFIX, 4, 4, 0}, // up arrow through circle
{U"\x29BE",    MATHML_OP_INFIX, 4, 4, 0}, // circled white bullet
{U"\x29BF",    MATHML_OP_INFIX, 4, 4, 0}, // circled bullet
{U"\x29C0",    MATHML_OP_INFIX, 5, 5, 0}, // circled less-than
{U"\x29C1",    MATHML_OP_INFIX, 5, 5, 0}, // circled greater-than
{U"\x29C2",    MATHML_OP_INFIX, 3, 3, 0}, // circle with small circle to the right
{U"\x29C3",    MATHML_OP_INFIX, 3, 3, 0}, // circle with two horizontal strokes to the right
{U"\x29C4",    MATHML_OP_INFIX, 4, 4, 0}, // squared rising diagonal slash
{U"\x29C5",    MATHML_OP_INFIX, 4, 4, 0}, // squared falling diagonal slash
{U"\x29C6",    MATHML_OP_INFIX, 4, 4, 0}, // squared asterisk
{U"\x29C7",    MATHML_OP_INFIX, 4, 4, 0}, // squared small circle
{U"\x29C8",    MATHML_OP_INFIX, 4, 4, 0}, // squared square
{U"\x29C9",    MATHML_OP_INFIX, 3, 3, 0}, // two joined squares
{U"\x29CA",    MATHML_OP_INFIX, 3, 3, 0}, // triangle with dot above
{U"\x29CB",    MATHML_OP_INFIX, 3, 3, 0}, // triangle with underbar
{U"\x29CC",    MATHML_OP_INFIX, 3, 3, 0}, // s in triangle
{U"\x29CD",    MATHML_OP_INFIX, 3, 3, 0}, // triangle with serifs at bottom
{U"\x29CE",    MATHML_OP_INFIX, 5, 5, 0}, // right triangle above left triangle
{U"\x29CF",    MATHML_OP_INFIX, 5, 5, 0}, // &LeftTriangleBar;
{U"\x29CF\x0338",    MATHML_OP_INFIX, 5, 5, 0}, // &NotLeftTriangleBar;
{U"\x29D0",    MATHML_OP_INFIX, 5, 5, 0}, // &RightTriangleBar;
{U"\x29D0\x0338",    MATHML_OP_INFIX, 5, 5, 0}, // &NotRightTriangleBar;
{U"\x29D1",    MATHML_OP_INFIX, 5, 5, 0}, // bowtie with left half black
{U"\x29D2",    MATHML_OP_INFIX, 5, 5, 0}, // bowtie with right half black
{U"\x29D3",    MATHML_OP_INFIX, 5, 5, 0}, // black bowtie
{U"\x29D4",    MATHML_OP_INFIX, 5, 5, 0}, // times with left half black
{U"\x29D5",    MATHML_OP_INFIX, 5, 5, 0}, // times with right half black
{U"\x29D6",    MATHML_OP_INFIX, 4, 4, 0}, // white hourglass
{U"\x29D7",    MATHML_OP_INFIX, 4, 4, 0}, // black hourglass
{U"\x29D8",    MATHML_OP_INFIX, 3, 3, 0}, // left wiggly fence
{U"\x29D9",    MATHML_OP_INFIX, 3, 3, 0}, // right wiggly fence
{U"\x29DB",    MATHML_OP_INFIX, 3, 3, 0}, // right double wiggly fence
{U"\x29DC",    MATHML_OP_INFIX, 3, 3, 0}, // incomplete infinity
{U"\x29DD",    MATHML_OP_INFIX, 3, 3, 0}, // tie over infinity
{U"\x29DE",    MATHML_OP_INFIX, 5, 5, 0}, // infinity negated with vertical bar
{U"\x29DF",    MATHML_OP_INFIX, 3, 3, 0}, // double-ended multimap
{U"\x29E0",    MATHML_OP_INFIX, 3, 3, 0}, // square with contoured outline
{U"\x29E1",    MATHML_OP_INFIX, 5, 5, 0}, // increases as
{U"\x29E2",    MATHML_OP_INFIX, 4, 4, 0}, // shuffle product
{U"\x29E3",    MATHML_OP_INFIX, 5, 5, 0}, // equals sign and slanted parallel
{U"\x29E4",    MATHML_OP_INFIX, 5, 5, 0}, // equals sign and slanted parallel with tilde above
{U"\x29E5",    MATHML_OP_INFIX, 5, 5, 0}, // identical to and slanted parallel
{U"\x29E6",    MATHML_OP_INFIX, 5, 5, 0}, // gleich stark
{U"\x29E7",    MATHML_OP_INFIX, 3, 3, 0}, // thermodynamic
{U"\x29E8",    MATHML_OP_INFIX, 3, 3, 0}, // down-pointing triangle with left half black
{U"\x29E9",    MATHML_OP_INFIX, 3, 3, 0}, // down-pointing triangle with right half black
{U"\x29EA",    MATHML_OP_INFIX, 3, 3, 0}, // black diamond with down arrow
{U"\x29EB",    MATHML_OP_INFIX, 3, 3, 0}, // black lozenge
{U"\x29EC",    MATHML_OP_INFIX, 3, 3, 0}, // white circle with down arrow
{U"\x29ED",    MATHML_OP_INFIX, 3, 3, 0}, // black circle with down arrow
{U"\x29EE",    MATHML_OP_INFIX, 3, 3, 0}, // error-barred white square
{U"\x29EF",    MATHML_OP_INFIX, 3, 3, 0}, // error-barred black square
{U"\x29F0",    MATHML_OP_INFIX, 3, 3, 0}, // error-barred white diamond
{U"\x29F1",    MATHML_OP_INFIX, 3, 3, 0}, // error-barred black diamond
{U"\x29F2",    MATHML_OP_INFIX, 3, 3, 0}, // error-barred white circle
{U"\x29F3",    MATHML_OP_INFIX, 3, 3, 0}, // error-barred black circle
{U"\x29F4",    MATHML_OP_INFIX, 5, 5, 0}, // rule-delayed
{U"\x29F5",    MATHML_OP_INFIX, 4, 4, 0}, // reverse solidus operator
{U"\x29F6",    MATHML_OP_INFIX, 4, 4, 0}, // solidus with overbar
{U"\x29F7",    MATHML_OP_INFIX, 4, 4, 0}, // reverse solidus with horizontal stroke
{U"\x29F8",    MATHML_OP_INFIX, 3, 3, 0}, // big solidus
{U"\x29F9",    MATHML_OP_INFIX, 3, 3, 0}, // big reverse solidus
{U"\x29FA",    MATHML_OP_INFIX, 3, 3, 0}, // double plus
{U"\x29FB",    MATHML_OP_INFIX, 3, 3, 0}, // triple plus
{U"\x29FC",   MATHML_OP_PREFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // left-pointing curved angle bracket
{U"\x29FD",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_FENCE|MATHML_OP_SYMMETRIC|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // right-pointing curved angle bracket
{U"\x29FE",    MATHML_OP_INFIX, 4, 4, 0}, // tiny
{U"\x29FF",    MATHML_OP_INFIX, 4, 4, 0}, // miny
{U"\x2A00",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_MOVABLELIMITS|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // &bigodot;
{U"\x2A01",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_MOVABLELIMITS|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // &bigoplus;
{U"\x2A02",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_MOVABLELIMITS|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // &bigotimes;
{U"\x2A03",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_MOVABLELIMITS|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // n-ary union operator with dot
{U"\x2A04",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_MOVABLELIMITS|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // &biguplus;
{U"\x2A05",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_MOVABLELIMITS|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // n-ary square intersection operator
{U"\x2A06",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_MOVABLELIMITS|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // &bigsqcup;
{U"\x2A07",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_MOVABLELIMITS|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // two logical and operator
{U"\x2A08",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_MOVABLELIMITS|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // two logical or operator
{U"\x2A09",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_MOVABLELIMITS|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // n-ary times operator
{U"\x2A0A",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_MOVABLELIMITS|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_MIRRORABLE}, // modulo two sum
{U"\x2A0B",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_INTEGRAL|MATHML_OP_MIRRORABLE}, // summation with integral
{U"\x2A0C",   MATHML_OP_PREFIX, 0, 1, MATHML_OP_LARGEOP|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_INTEGRAL|MATHML_OP_MIRRORABLE}, // quadruple integral operator
{U"\x2A0D",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_INTEGRAL|MATHML_OP_MIRRORABLE}, // finite part integral
{U"\x2A0E",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_INTEGRAL|MATHML_OP_MIRRORABLE}, // integral with double stroke
{U"\x2A0F",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_INTEGRAL|MATHML_OP_MIRRORABLE}, // integral average with slash
{U"\x2A10",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_MOVABLELIMITS|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_INTEGRAL|MATHML_OP_MIRRORABLE}, // circulation function
{U"\x2A11",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_MOVABLELIMITS|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_INTEGRAL}, // anticlockwise integration
{U"\x2A12",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_MOVABLELIMITS|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_INTEGRAL|MATHML_OP_MIRRORABLE}, // line integration with rectangular path around pole
{U"\x2A13",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_MOVABLELIMITS|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_INTEGRAL|MATHML_OP_MIRRORABLE}, // line integration with semicircular path around pole
{U"\x2A14",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_MOVABLELIMITS|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_INTEGRAL|MATHML_OP_MIRRORABLE}, // line integration not including the pole
{U"\x2A15",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_INTEGRAL|MATHML_OP_MIRRORABLE}, // integral around a point operator
{U"\x2A16",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_INTEGRAL|MATHML_OP_MIRRORABLE}, // quaternion integral operator
{U"\x2A17",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_SYMMETRIC|MATHML_OP_INTEGRAL|MATHML_OP_MIRRORABLE|MATHML_OP_VERTICAL}, // integral with leftwards arrow with hook
{U"\x2A18",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_INTEGRAL|MATHML_OP_MIRRORABLE}, // integral with times sign
{U"\x2A19",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_INTEGRAL|MATHML_OP_MIRRORABLE}, // integral with intersection
{U"\x2A1A",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_INTEGRAL|MATHML_OP_MIRRORABLE}, // integral with union
{U"\x2A1B",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_INTEGRAL|MATHML_OP_MIRRORABLE}, // integral with overbar
{U"\x2A1C",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL|MATHML_OP_INTEGRAL|MATHML_OP_MIRRORABLE}, // integral with underbar
{U"\x2A1D",    MATHML_OP_INFIX, 3, 3, 0}, // join
{U"\x2A1E",    MATHML_OP_INFIX, 3, 3, 0}, // large left triangle operator
{U"\x2A1F",    MATHML_OP_INFIX, 3, 3, 0}, // z notation schema composition
{U"\x2A20",    MATHML_OP_INFIX, 3, 3, 0}, // z notation schema piping
{U"\x2A21",    MATHML_OP_INFIX, 3, 3, 0}, // z notation schema projection
{U"\x2A22",    MATHML_OP_INFIX, 4, 4, 0}, // plus sign with small circle above
{U"\x2A23",    MATHML_OP_INFIX, 4, 4, 0}, // plus sign with circumflex accent above
{U"\x2A24",    MATHML_OP_INFIX, 4, 4, 0}, // plus sign with tilde above
{U"\x2A25",    MATHML_OP_INFIX, 4, 4, 0}, // plus sign with dot below
{U"\x2A26",    MATHML_OP_INFIX, 4, 4, 0}, // plus sign with tilde below
{U"\x2A27",    MATHML_OP_INFIX, 4, 4, 0}, // plus sign with subscript two
{U"\x2A28",    MATHML_OP_INFIX, 4, 4, 0}, // plus sign with black triangle
{U"\x2A29",    MATHML_OP_INFIX, 4, 4, 0}, // minus sign with comma above
{U"\x2A2A",    MATHML_OP_INFIX, 4, 4, 0}, // minus sign with dot below
{U"\x2A2B",    MATHML_OP_INFIX, 4, 4, 0}, // minus sign with falling dots
{U"\x2A2C",    MATHML_OP_INFIX, 4, 4, 0}, // minus sign with rising dots
{U"\x2A2D",    MATHML_OP_INFIX, 4, 4, 0}, // plus sign in left half circle
{U"\x2A2E",    MATHML_OP_INFIX, 4, 4, 0}, // plus sign in right half circle
{U"\x2A2F",    MATHML_OP_INFIX, 4, 4, 0}, // &Cross;
{U"\x2A30",    MATHML_OP_INFIX, 4, 4, 0}, // multiplication sign with dot above
{U"\x2A31",    MATHML_OP_INFIX, 4, 4, 0}, // multiplication sign with underbar
{U"\x2A32",    MATHML_OP_INFIX, 4, 4, 0}, // semidirect product with bottom closed
{U"\x2A33",    MATHML_OP_INFIX, 4, 4, 0}, // smash product
{U"\x2A34",    MATHML_OP_INFIX, 4, 4, 0}, // multiplication sign in left half circle
{U"\x2A35",    MATHML_OP_INFIX, 4, 4, 0}, // multiplication sign in right half circle
{U"\x2A36",    MATHML_OP_INFIX, 4, 4, 0}, // circled multiplication sign with circumflex accent
{U"\x2A37",    MATHML_OP_INFIX, 4, 4, 0}, // multiplication sign in double circle
{U"\x2A38",    MATHML_OP_INFIX, 4, 4, 0}, // circled division sign
{U"\x2A39",    MATHML_OP_INFIX, 4, 4, 0}, // plus sign in triangle
{U"\x2A3A",    MATHML_OP_INFIX, 4, 4, 0}, // minus sign in triangle
{U"\x2A3B",    MATHML_OP_INFIX, 4, 4, 0}, // multiplication sign in triangle
{U"\x2A3C",    MATHML_OP_INFIX, 4, 4, 0}, // interior product
{U"\x2A3D",    MATHML_OP_INFIX, 4, 4, 0}, // righthand interior product
{U"\x2A3E",    MATHML_OP_INFIX, 4, 4, 0}, // z notation relational composition
{U"\x2A3F",    MATHML_OP_INFIX, 4, 4, 0}, // amalgamation or coproduct
{U"\x2A40",    MATHML_OP_INFIX, 4, 4, 0}, // intersection with dot
{U"\x2A41",    MATHML_OP_INFIX, 4, 4, 0}, // union with minus sign
{U"\x2A42",    MATHML_OP_INFIX, 4, 4, 0}, // union with overbar
{U"\x2A43",    MATHML_OP_INFIX, 4, 4, 0}, // intersection with overbar
{U"\x2A44",    MATHML_OP_INFIX, 4, 4, 0}, // intersection with logical and
{U"\x2A45",    MATHML_OP_INFIX, 4, 4, 0}, // union with logical or
{U"\x2A46",    MATHML_OP_INFIX, 4, 4, 0}, // union above intersection
{U"\x2A47",    MATHML_OP_INFIX, 4, 4, 0}, // intersection above union
{U"\x2A48",    MATHML_OP_INFIX, 4, 4, 0}, // union above bar above intersection
{U"\x2A49",    MATHML_OP_INFIX, 4, 4, 0}, // intersection above bar above union
{U"\x2A4A",    MATHML_OP_INFIX, 4, 4, 0}, // union beside and joined with union
{U"\x2A4B",    MATHML_OP_INFIX, 4, 4, 0}, // intersection beside and joined with intersection
{U"\x2A4C",    MATHML_OP_INFIX, 4, 4, 0}, // closed union with serifs
{U"\x2A4D",    MATHML_OP_INFIX, 4, 4, 0}, // closed intersection with serifs
{U"\x2A4E",    MATHML_OP_INFIX, 4, 4, 0}, // double square intersection
{U"\x2A4F",    MATHML_OP_INFIX, 4, 4, 0}, // double square union
{U"\x2A50",    MATHML_OP_INFIX, 4, 4, 0}, // closed union with serifs and smash product
{U"\x2A51",    MATHML_OP_INFIX, 4, 4, 0}, // logical and with dot above
{U"\x2A52",    MATHML_OP_INFIX, 4, 4, 0}, // logical or with dot above
{U"\x2A53",    MATHML_OP_INFIX, 4, 4, MATHML_OP_VERTICAL}, // &And;
{U"\x2A54",    MATHML_OP_INFIX, 4, 4, MATHML_OP_VERTICAL}, // &Or;
{U"\x2A55",    MATHML_OP_INFIX, 4, 4, 0}, // two intersecting logical and
{U"\x2A56",    MATHML_OP_INFIX, 4, 4, 0}, // two intersecting logical or
{U"\x2A57",    MATHML_OP_INFIX, 4, 4, 0}, // sloping large or
{U"\x2A58",    MATHML_OP_INFIX, 4, 4, 0}, // sloping large and
{U"\x2A59",    MATHML_OP_INFIX, 5, 5, 0}, // logical or overlapping logical and
{U"\x2A5A",    MATHML_OP_INFIX, 4, 4, 0}, // logical and with middle stem
{U"\x2A5B",    MATHML_OP_INFIX, 4, 4, 0}, // logical or with middle stem
{U"\x2A5C",    MATHML_OP_INFIX, 4, 4, 0}, // logical and with horizontal dash
{U"\x2A5D",    MATHML_OP_INFIX, 4, 4, 0}, // logical or with horizontal dash
{U"\x2A5E",    MATHML_OP_INFIX, 4, 4, 0}, // logical and with double overbar
{U"\x2A5F",    MATHML_OP_INFIX, 4, 4, 0}, // logical and with underbar
{U"\x2A60",    MATHML_OP_INFIX, 4, 4, 0}, // logical and with double underbar
{U"\x2A61",    MATHML_OP_INFIX, 4, 4, 0}, // small vee with underbar
{U"\x2A62",    MATHML_OP_INFIX, 4, 4, 0}, // logical or with double overbar
{U"\x2A63",    MATHML_OP_INFIX, 4, 4, 0}, // logical or with double underbar
{U"\x2A64",    MATHML_OP_INFIX, 4, 4, 0}, // z notation domain antirestriction
{U"\x2A65",    MATHML_OP_INFIX, 4, 4, 0}, // z notation range antirestriction
{U"\x2A66",    MATHML_OP_INFIX, 5, 5, 0}, // equals sign with dot below
{U"\x2A67",    MATHML_OP_INFIX, 5, 5, 0}, // identical with dot above
{U"\x2A68",    MATHML_OP_INFIX, 5, 5, 0}, // triple horizontal bar with double vertical stroke
{U"\x2A69",    MATHML_OP_INFIX, 5, 5, 0}, // triple horizontal bar with triple vertical stroke
{U"\x2A6A",    MATHML_OP_INFIX, 5, 5, 0}, // tilde operator with dot above
{U"\x2A6B",    MATHML_OP_INFIX, 5, 5, 0}, // tilde operator with rising dots
{U"\x2A6C",    MATHML_OP_INFIX, 5, 5, 0}, // similar minus similar
{U"\x2A6D",    MATHML_OP_INFIX, 5, 5, 0}, // congruent with dot above
{U"\x2A6E",    MATHML_OP_INFIX, 5, 5, 0}, // equals with asterisk
{U"\x2A6F",    MATHML_OP_INFIX, 5, 5, 0}, // almost equal to with circumflex accent
{U"\x2A70",    MATHML_OP_INFIX, 5, 5, 0}, // approximately equal or equal to
{U"\x2A71",    MATHML_OP_INFIX, 4, 4, 0}, // equals sign above plus sign
{U"\x2A72",    MATHML_OP_INFIX, 4, 4, 0}, // plus sign above equals sign
{U"\x2A73",    MATHML_OP_INFIX, 5, 5, 0}, // equals sign above tilde operator
{U"\x2A74",    MATHML_OP_INFIX, 5, 5, 0}, // double colon equal
{U"\x2A75",    MATHML_OP_INFIX, 5, 5, 0}, // &Equal;
{U"\x2A76",    MATHML_OP_INFIX, 5, 5, 0}, // three consecutive equals signs
{U"\x2A77",    MATHML_OP_INFIX, 5, 5, 0}, // equals sign with two dots above and two dots below
{U"\x2A78",    MATHML_OP_INFIX, 5, 5, 0}, // equivalent with four dots above
{U"\x2A79",    MATHML_OP_INFIX, 5, 5, 0}, // less-than with circle inside
{U"\x2A7A",    MATHML_OP_INFIX, 5, 5, 0}, // greater-than with circle inside
{U"\x2A7B",    MATHML_OP_INFIX, 5, 5, 0}, // less-than with question mark above
{U"\x2A7C",    MATHML_OP_INFIX, 5, 5, 0}, // greater-than with question mark above
{U"\x2A7D",    MATHML_OP_INFIX, 5, 5, 0}, // &LessSlantEqual;
{U"\x2A7D\x0338",    MATHML_OP_INFIX, 5, 5, 0}, // &NotLessSlantEqual;
{U"\x2A7E",    MATHML_OP_INFIX, 5, 5, 0}, // &GreaterSlantEqual;
{U"\x2A7E\x0338",    MATHML_OP_INFIX, 5, 5, 0}, // &NotGreaterSlantEqual;
{U"\x2A7F",    MATHML_OP_INFIX, 5, 5, 0}, // less-than or slanted equal to with dot inside
{U"\x2A80",    MATHML_OP_INFIX, 5, 5, 0}, // greater-than or slanted equal to with dot inside
{U"\x2A81",    MATHML_OP_INFIX, 5, 5, 0}, // less-than or slanted equal to with dot above
{U"\x2A82",    MATHML_OP_INFIX, 5, 5, 0}, // greater-than or slanted equal to with dot above
{U"\x2A83",    MATHML_OP_INFIX, 5, 5, 0}, // less-than or slanted equal to with dot above right
{U"\x2A84",    MATHML_OP_INFIX, 5, 5, 0}, // greater-than or slanted equal to with dot above left
{U"\x2A85",    MATHML_OP_INFIX, 5, 5, 0}, // &lessapprox;
{U"\x2A86",    MATHML_OP_INFIX, 5, 5, 0}, // &gtrapprox;
{U"\x2A87",    MATHML_OP_INFIX, 5, 5, 0}, // less-than and single-line not equal to
{U"\x2A88",    MATHML_OP_INFIX, 5, 5, 0}, // greater-than and single-line not equal to
{U"\x2A89",    MATHML_OP_INFIX, 5, 5, 0}, // less-than and not approximate
{U"\x2A8A",    MATHML_OP_INFIX, 5, 5, 0}, // greater-than and not approximate
{U"\x2A8B",    MATHML_OP_INFIX, 5, 5, 0}, // &lesseqqgtr;
{U"\x2A8C",    MATHML_OP_INFIX, 5, 5, 0}, // &gtreqqless;
{U"\x2A8D",    MATHML_OP_INFIX, 5, 5, 0}, // less-than above similar or equal
{U"\x2A8E",    MATHML_OP_INFIX, 5, 5, 0}, // greater-than above similar or equal
{U"\x2A8F",    MATHML_OP_INFIX, 5, 5, 0}, // less-than above similar above greater-than
{U"\x2A90",    MATHML_OP_INFIX, 5, 5, 0}, // greater-than above similar above less-than
{U"\x2A91",    MATHML_OP_INFIX, 5, 5, 0}, // less-than above greater-than above double-line equal
{U"\x2A92",    MATHML_OP_INFIX, 5, 5, 0}, // greater-than above less-than above double-line equal
{U"\x2A93",    MATHML_OP_INFIX, 5, 5, 0}, // less-than above slanted equal above greater-than above slanted equal
{U"\x2A94",    MATHML_OP_INFIX, 5, 5, 0}, // greater-than above slanted equal above less-than above slanted equal
{U"\x2A95",    MATHML_OP_INFIX, 5, 5, 0}, // slanted equal to or less-than
{U"\x2A96",    MATHML_OP_INFIX, 5, 5, 0}, // slanted equal to or greater-than
{U"\x2A97",    MATHML_OP_INFIX, 5, 5, 0}, // slanted equal to or less-than with dot inside
{U"\x2A98",    MATHML_OP_INFIX, 5, 5, 0}, // slanted equal to or greater-than with dot inside
{U"\x2A99",    MATHML_OP_INFIX, 5, 5, 0}, // double-line equal to or less-than
{U"\x2A9A",    MATHML_OP_INFIX, 5, 5, 0}, // double-line equal to or greater-than
{U"\x2A9B",    MATHML_OP_INFIX, 5, 5, 0}, // double-line slanted equal to or less-than
{U"\x2A9C",    MATHML_OP_INFIX, 5, 5, 0}, // double-line slanted equal to or greater-than
{U"\x2A9D",    MATHML_OP_INFIX, 5, 5, 0}, // similar or less-than
{U"\x2A9E",    MATHML_OP_INFIX, 5, 5, 0}, // similar or greater-than
{U"\x2A9F",    MATHML_OP_INFIX, 5, 5, 0}, // similar above less-than above equals sign
{U"\x2AA0",    MATHML_OP_INFIX, 5, 5, 0}, // similar above greater-than above equals sign
{U"\x2AA1",    MATHML_OP_INFIX, 5, 5, 0}, // &LessLess;
{U"\x2AA1\x0338",    MATHML_OP_INFIX, 5, 5, 0}, // &NotNestedLessLess;
{U"\x2AA2",    MATHML_OP_INFIX, 5, 5, 0}, // &GreaterGreater;
{U"\x2AA2\x0338",    MATHML_OP_INFIX, 5, 5, 0}, // &NotNestedGreaterGreater;
{U"\x2AA3",    MATHML_OP_INFIX, 5, 5, 0}, // double nested less-than with underbar
{U"\x2AA4",    MATHML_OP_INFIX, 5, 5, 0}, // greater-than overlapping less-than
{U"\x2AA5",    MATHML_OP_INFIX, 5, 5, 0}, // greater-than beside less-than
{U"\x2AA6",    MATHML_OP_INFIX, 5, 5, 0}, // less-than closed by curve
{U"\x2AA7",    MATHML_OP_INFIX, 5, 5, 0}, // greater-than closed by curve
{U"\x2AA8",    MATHML_OP_INFIX, 5, 5, 0}, // less-than closed by curve above slanted equal
{U"\x2AA9",    MATHML_OP_INFIX, 5, 5, 0}, // greater-than closed by curve above slanted equal
{U"\x2AAA",    MATHML_OP_INFIX, 5, 5, 0}, // smaller than
{U"\x2AAB",    MATHML_OP_INFIX, 5, 5, 0}, // larger than
{U"\x2AAC",    MATHML_OP_INFIX, 5, 5, 0}, // smaller than or equal to
{U"\x2AAD",    MATHML_OP_INFIX, 5, 5, 0}, // larger than or equal to
{U"\x2AAE",    MATHML_OP_INFIX, 5, 5, 0}, // equals sign with bumpy above
{U"\x2AAF",    MATHML_OP_INFIX, 5, 5, 0}, // &PrecedesEqual;
{U"\x2AAF\x0338",    MATHML_OP_INFIX, 5, 5, 0}, // &NotPrecedesEqual;
{U"\x2AB0",    MATHML_OP_INFIX, 5, 5, 0}, // &SucceedsEqual;
{U"\x2AB0\x0338",    MATHML_OP_INFIX, 5, 5, 0}, // &NotSucceedsEqual;
{U"\x2AB1",    MATHML_OP_INFIX, 5, 5, 0}, // precedes above single-line not equal to
{U"\x2AB2",    MATHML_OP_INFIX, 5, 5, 0}, // succeeds above single-line not equal to
{U"\x2AB3",    MATHML_OP_INFIX, 5, 5, 0}, // &prE;
{U"\x2AB4",    MATHML_OP_INFIX, 5, 5, 0}, // &scE;
{U"\x2AB5",    MATHML_OP_INFIX, 5, 5, 0}, // precedes above not equal to
{U"\x2AB6",    MATHML_OP_INFIX, 5, 5, 0}, // succeeds above not equal to
{U"\x2AB7",    MATHML_OP_INFIX, 5, 5, 0}, // &precapprox;
{U"\x2AB8",    MATHML_OP_INFIX, 5, 5, 0}, // &succapprox;
{U"\x2AB9",    MATHML_OP_INFIX, 5, 5, 0}, // precedes above not almost equal to
{U"\x2ABA",    MATHML_OP_INFIX, 5, 5, 0}, // succeeds above not almost equal to
{U"\x2ABB",    MATHML_OP_INFIX, 5, 5, 0}, // double precedes
{U"\x2ABC",    MATHML_OP_INFIX, 5, 5, 0}, // double succeeds
{U"\x2ABD",    MATHML_OP_INFIX, 5, 5, 0}, // subset with dot
{U"\x2ABE",    MATHML_OP_INFIX, 5, 5, 0}, // superset with dot
{U"\x2ABF",    MATHML_OP_INFIX, 5, 5, 0}, // subset with plus sign below
{U"\x2AC0",    MATHML_OP_INFIX, 5, 5, 0}, // superset with plus sign below
{U"\x2AC1",    MATHML_OP_INFIX, 5, 5, 0}, // subset with multiplication sign below
{U"\x2AC2",    MATHML_OP_INFIX, 5, 5, 0}, // superset with multiplication sign below
{U"\x2AC3",    MATHML_OP_INFIX, 5, 5, 0}, // subset of or equal to with dot above
{U"\x2AC4",    MATHML_OP_INFIX, 5, 5, 0}, // superset of or equal to with dot above
{U"\x2AC5",    MATHML_OP_INFIX, 5, 5, 0}, // &subseteqq;
{U"\x2AC5\x0338",    MATHML_OP_INFIX, 5, 5, 0}, // &nsubseteqq;
{U"\x2AC6",    MATHML_OP_INFIX, 5, 5, 0}, // &supseteqq;
{U"\x2AC6\x0338",    MATHML_OP_INFIX, 5, 5, 0}, // &nsubseteqq;
{U"\x2AC7",    MATHML_OP_INFIX, 5, 5, 0}, // subset of above tilde operator
{U"\x2AC8",    MATHML_OP_INFIX, 5, 5, 0}, // superset of above tilde operator
{U"\x2AC9",    MATHML_OP_INFIX, 5, 5, 0}, // subset of above almost equal to
{U"\x2ACA",    MATHML_OP_INFIX, 5, 5, 0}, // superset of above almost equal to
{U"\x2ACB",    MATHML_OP_INFIX, 5, 5, 0}, // subset of above not equal to
{U"\x2ACC",    MATHML_OP_INFIX, 5, 5, 0}, // superset of above not equal to
{U"\x2ACD",    MATHML_OP_INFIX, 5, 5, 0}, // square left open box operator
{U"\x2ACE",    MATHML_OP_INFIX, 5, 5, 0}, // square right open box operator
{U"\x2ACF",    MATHML_OP_INFIX, 5, 5, 0}, // closed subset
{U"\x2AD0",    MATHML_OP_INFIX, 5, 5, 0}, // closed superset
{U"\x2AD1",    MATHML_OP_INFIX, 5, 5, 0}, // closed subset or equal to
{U"\x2AD2",    MATHML_OP_INFIX, 5, 5, 0}, // closed superset or equal to
{U"\x2AD3",    MATHML_OP_INFIX, 5, 5, 0}, // subset above superset
{U"\x2AD4",    MATHML_OP_INFIX, 5, 5, 0}, // superset above subset
{U"\x2AD5",    MATHML_OP_INFIX, 5, 5, 0}, // subset above subset
{U"\x2AD6",    MATHML_OP_INFIX, 5, 5, 0}, // superset above superset
{U"\x2AD7",    MATHML_OP_INFIX, 5, 5, 0}, // superset beside subset
{U"\x2AD8",    MATHML_OP_INFIX, 5, 5, 0}, // superset beside and joined by dash with subset
{U"\x2AD9",    MATHML_OP_INFIX, 5, 5, 0}, // element of opening downwards
{U"\x2ADA",    MATHML_OP_INFIX, 5, 5, 0}, // pitchfork with tee top
{U"\x2ADB",    MATHML_OP_INFIX, 5, 5, 0}, // transversal intersection
{U"\x2ADC",    MATHML_OP_INFIX, 5, 5, 0}, // forking
{U"\x2ADD",    MATHML_OP_INFIX, 5, 5, 0}, // nonforking
{U"\x2ADD\x0338",    MATHML_OP_INFIX, 5, 5, 0}, // nonforking with slash
{U"\x2ADE",    MATHML_OP_INFIX, 5, 5, 0}, // short left tack
{U"\x2ADF",    MATHML_OP_INFIX, 5, 5, 0}, // short down tack
{U"\x2AE0",    MATHML_OP_INFIX, 5, 5, 0}, // short up tack
{U"\x2AE1",    MATHML_OP_INFIX, 5, 5, 0}, // perpendicular with s
{U"\x2AE2",    MATHML_OP_INFIX, 5, 5, 0}, // vertical bar triple right turnstile
{U"\x2AE3",    MATHML_OP_INFIX, 5, 5, 0}, // double vertical bar left turnstile
{U"\x2AE4",    MATHML_OP_INFIX, 5, 5, 0}, // &DoubleLeftTee;
{U"\x2AE5",    MATHML_OP_INFIX, 5, 5, 0}, // double vertical bar double left turnstile
{U"\x2AE6",    MATHML_OP_INFIX, 5, 5, 0}, // long dash from left member of double vertical
{U"\x2AE7",    MATHML_OP_INFIX, 5, 5, 0}, // short down tack with overbar
{U"\x2AE8",    MATHML_OP_INFIX, 5, 5, 0}, // short up tack with underbar
{U"\x2AE9",    MATHML_OP_INFIX, 5, 5, 0}, // short up tack above short down tack
{U"\x2AEA",    MATHML_OP_INFIX, 5, 5, 0}, // double down tack
{U"\x2AEB",    MATHML_OP_INFIX, 5, 5, 0}, // double up tack
{U"\x2AEC",    MATHML_OP_INFIX, 5, 5, 0}, // double stroke not sign
{U"\x2AEC",   MATHML_OP_PREFIX, 0, 5, 0}, // &Not;
{U"\x2AED",    MATHML_OP_INFIX, 5, 5, 0}, // reversed double stroke not sign
{U"\x2AEE",    MATHML_OP_INFIX, 5, 5, 0}, // does not divide with reversed negation slash
{U"\x2AEF",    MATHML_OP_INFIX, 5, 5, 0}, // vertical line with circle above
{U"\x2AF0",    MATHML_OP_INFIX, 5, 5, 0}, // vertical line with circle below
{U"\x2AF1",    MATHML_OP_INFIX, 5, 5, 0}, // down tack with circle below
{U"\x2AF2",    MATHML_OP_INFIX, 5, 5, 0}, // parallel with horizontal stroke
{U"\x2AF3",    MATHML_OP_INFIX, 5, 5, 0}, // parallel with tilde operator
{U"\x2AF4",    MATHML_OP_INFIX, 4, 4, 0}, // triple vertical bar binary relation
{U"\x2AF5",    MATHML_OP_INFIX, 4, 4, 0}, // triple vertical bar with horizontal stroke
{U"\x2AF6",    MATHML_OP_INFIX, 4, 4, 0}, // triple colon operator
{U"\x2AF7",    MATHML_OP_INFIX, 5, 5, 0}, // triple nested less-than
{U"\x2AF8",    MATHML_OP_INFIX, 5, 5, 0}, // triple nested greater-than
{U"\x2AF9",    MATHML_OP_INFIX, 5, 5, 0}, // double-line slanted less-than or equal to
{U"\x2AFA",    MATHML_OP_INFIX, 5, 5, 0}, // double-line slanted greater-than or equal to
{U"\x2AFB",    MATHML_OP_INFIX, 4, 4, 0}, // triple solidus binary relation
{U"\x2AFC",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_MOVABLELIMITS|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // large triple vertical bar operator
{U"\x2AFD",    MATHML_OP_INFIX, 4, 4, 0}, // double solidus operator
{U"\x2AFE",    MATHML_OP_INFIX, 3, 3, 0}, // white vertical bar
{U"\x2AFF",   MATHML_OP_PREFIX, 1, 2, MATHML_OP_LARGEOP|MATHML_OP_MOVABLELIMITS|MATHML_OP_SYMMETRIC|MATHML_OP_VERTICAL}, // n-ary white vertical bar
{U"\x2B45",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_HORIZONTAL}, // leftwards quadruple arrow
{U"\x2B46",    MATHML_OP_INFIX, 5, 5, MATHML_OP_STRETCHY|MATHML_OP_HORIZONTAL}, // rightwards quadruple arrow
{U"\xFE35",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &OverParenthesis; (MathML 2.0)
{U"\xFE36",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &UnderParenthesis; (MathML 2.0)
{U"\xFE37",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &OverBrace; (MathML 2.0)
{U"\xFE38",  MATHML_OP_POSTFIX, 0, 0, MATHML_OP_STRETCHY|MATHML_OP_ACCENT|MATHML_OP_HORIZONTAL}, // &UnderBrace; (MathML 2.0)
